<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use App\Utilities\Common;
use App\Models\IpnNotification;

class ResendIPN extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'command:resendIPN';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Reenvia la notificación por ipn en caso de que no responda OK en el primer intento.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $pendings = IpnNotification::where('status', 'S')
                                    ->get();

        foreach($pendings as $pending){
            $resIPN = json_decode($pending->data, true);

            $resp = Common::executeCurl($pending->end_point, 'POST', [], $resIPN);

            IpnNotification::insert([
                'end_point' => $pending->end_point,
                'transaction' => $pending->transaction,
                'unique_transaction' => $pending->unique_transaction,
                'n_notification' => ($pending->n_notification + 1),
                'data' => $pending->data,
                'response_code' => $resp['code'],
                'date_reg' => date('Y-m-d H:i:s'),
                'status' => $resp['code'] == 200? 'OK' : (($pending->n_notification + 1) < env('N_NOTIFICATION')? 'S' : 'F')
            ]);

            $pending->status = 'F';
            $pending->save();
        }
    }
}
