<?php

namespace App\Http\Controllers;

//Modelos
use App\Models\Client;
use App\Models\LogApiV2;
use App\Models\TempCar;
use App\Models\TempCarDetail;

//Otras clases
//use App\Utilities\CustomLogs;
use Illuminate\Http\Request;

class ClientController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    public function getClient(Request $request)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        $response = [
            'success' => false,
            'data' => [
                'cod_err' => 'ERR_PARAM',
                'msg' => 'Faltan parámetros.',
            ]
        ];

        $inputs = $request->input();

        if ((!empty($inputs['email']) ||
                !empty($inputs['phone'])) &&
            !empty($inputs['transaction'])
        ) {

            //Verificando si la transaccion es válida
            $transaction = TempCar::getTransaction(
                $inputs['transaction'],
                $request->bearerToken()
            );

            if (!empty($transaction)) {
                $clients = Client::getClients(
                    !empty($inputs['email']) ? $inputs['email'] : false,
                    !empty($inputs['phone']) ? $inputs['phone'] : false
                );

                if ($clients->count()) {
                    foreach ($clients as $client) {
                        $data[] = [
                            'id_client' => $client->dni,
                            'name' => $client->name . ' ' . $client->last_name,
                            'email' => !empty($client->email) ? $client->email : '',
                            'phone' => !empty($client->phone_home) ? $client->phone_home : '',
                            'phone_2' => !empty($client->phone) ? $client->phone : '',
                        ];
                    }

                    $response = [
                        'success' => true,
                        'data' => $data,
                    ];
                } else {
                    $response['data']['cod_err'] = 'CLIENT_NOTFOUNDD';
                    $response['data']['msg'] = 'No se consiguieron clientes.';
                }
            } else {
                $response['data']['cod_err'] = 'TR_NOTVALID';
                $response['data']['msg'] = 'Transacción no válida.';
            }
        }

        //Finalizando log
        LogApiV2::finishLog(
            $log,
            $response,
            0,
            $response['success'] ? 'D' : 'E',
            !$response['success'] ? $response['data']['msg'] : ''
        );

        return response()->json($response);
    }

    public function updateEmailClient(Request $request)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        $response = [
            'success' => false,
            'data' => [
                'cod_err' => 'ERR_PARAM',
                'msg' => 'Faltan parámetros.',
            ]
        ];

        $inputs = $request->input();

        if (!empty($inputs['id_client']) && (!empty($inputs['email']) || !empty($inputs['phone_2']))) {
            if (filter_var($inputs['email'], FILTER_VALIDATE_EMAIL)) {
                //Actualizando email del cliente
                if (!empty($inputs['email'])) {
                    Client::updateEmail($inputs['email'], $inputs['id_client']);
                }

                //Actualizando segundo teléfono de contacto del cliente
                if (!empty($inputs['phone_2'])) {
                    Client::updateSecondPhone($inputs['phone_2'], $inputs['id_client']);
                }

                $response = [
                    'success' => true,
                    'data' => [
                        'id_client' => $inputs['id_client'],
                        'msg' => 'Email actualizado exitosamente',
                    ],
                ];
            } else {
                $response['data']['cod_err'] = 'EMAIL_NOTVALID';
                $response['data']['msg'] = 'El email no es válido.';
            }
        }

        //Finalizando log
        LogApiV2::finishLog(
            $log,
            $response,
            0,
            $response['success'] ? 'D' : 'E',
            !$response['success'] ? $response['data']['msg'] : ''
        );

        return response()->json($response);
    }

    /*
  Registra los datos del cliente junto con los datos de envío seleccionados por el cliente.

  @param Illuminate\Http\Request $request
  @return Object
   */
    public function registerClient(Request $request)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        $response = [
            'success' => false,
            'data' => [
                'cod_err' => 'ERR_PARAM',
                'msg' => 'Faltan parámetros.',
            ],
        ];

        $inputs = $request->input();

        if (!empty($inputs['client']) && !empty($inputs['transaction'])) {
            //Verificando si la transaccion es válida
            $transaction = TempCar::getTransaction(
                $inputs['transaction'],
                $request->bearerToken(),
                'W'
            );
            
            $transactionD = TempCarDetail::getTransactionDetail(
                $inputs['transaction'],
                $request->bearerToken()
            );
            
            if (!empty($transaction) && count($transactionD)) {
                $date = date('Y-m-d H:i:s');

                if (
                    !empty($inputs['client']['name']) &&
                    !empty($inputs['client']['last_name']) &&
                    !empty($inputs['client']['email']) &&
                    filter_var($inputs['client']['email'], FILTER_VALIDATE_EMAIL) &&
                    !empty($inputs['client']['phone']) &&
                    !empty($inputs['client']['address'])
                ) {

                    $client = Client::getClient(
                        $inputs['client']['email'],
                        $inputs['client']['phone']
                    );

                    if (empty($client)) {
                        //Registrando los datos del cliente
                        $client = new Client;

                        if (!empty($inputs['client']['dni'])) {
                            $client->dni = $inputs['client']['dni'];
                        } else {
                            $client->dni = uniqid();
                        }

                        $client->name = $inputs['client']['name'];
                        $client->last_name = $inputs['client']['last_name'];
                        $client->address = $inputs['client']['address'];
                        $client->birthday = $date;
                        $client->email = $inputs['client']['email'];
                        $client->phone_home = $inputs['client']['phone'];
                        $client->date_reg = $date;

                        if (
                            !empty($inputs['client']['type_person']) &&
                            ($inputs['client']['type_person'] == 'F' ||
                                $inputs['client']['type_person'] == 'M')
                        ) {
                            $client->person_type = $inputs['client']['type_person'];
                        } else {
                            $client->person_type = 'F';
                        }

                        if (
                            !empty($inputs['client']['invoice']) &&
                            $inputs['client']['invoice'] == 'Y'
                        ) {
                            $client->require_invoice = $inputs['client']['invoice'];
                            $client->rfc = $inputs['client']['rfc'];
                        }

                        if (!empty($inputs['client']['campaign'])) {
                            $client->campaign = $inputs['client']['campaign'];
                            $client->social = 'S';
                        }

                        if (!empty($inputs['client']['phone_2'])) {
                            $client->phone = $inputs['client']['phone_2'];
                        }

                        $client->save();

                        $transaction->client_dni = $client->dni;
                        $transaction->save();

                        $response = [
                            'success' => true,
                            'data' => [
                                'transaction' => $inputs['transaction'],
                                'dni' => $client->dni,
                                'client' => $client->name . ' ' . $client->last_name,
                                'phone' => !empty($client->phone_home) ? $client->phone_home : 'N/A',
                                'email' => !empty($client->email) ? $client->email : 'N/A',
                            ],
                        ];
                    } else {
                        $response['data']['cod_err'] = 'ALREADY_REGISTERED_CLIENT';
                        $response['data']['msg'] = 'Cliente ya registrado.';
                    }
                }
            } else {
                $response['data']['cod_err'] = 'TR_NOTVALID';
                $response['data']['msg'] = 'Transacción no válida.';
            }
        }

        //Finalizando log
        LogApiV2::finishLog(
            $log,
            $response,
            0,
            $response['success'] ? 'D' : 'E',
            !$response['success'] ? $response['data']['msg'] : ''
        );

        return response()->json($response);
    }

    /**
     * [getClientCode Consulta el codigo de referido de un cliente]
     * @param  Request $request [se recibe el codigo de referido]
     * @return [type]           [description]
     */
    public function getClientCode(Request $request)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        $response = [
            'success' => false,
            'data' => [
                'cod_err' => 'ERR_PARAM',
                'msg' => 'Faltan parámetros.',
            ],
        ];

        $inputs = $request->input();

        if (!empty($inputs['code_ref'])) {

            $code_ref = strtoupper($inputs['code_ref']);
            $infoCode = Client::getClientByCodeR(trim(
                $code_ref
            ));

            if (!empty($infoCode)) {

                $response = [
                    'success' => true,
                    'data' => [
                        'type_code' => "CODE_REF",
                        'dni' => $infoCode->dni,
                        'client' => $infoCode->name . ' ' . $infoCode->last_name,
                        'phone' => !empty($infoCode->phone_home) ? $infoCode->phone_home : 'N/A',
                        'email' => !empty($infoCode->email) ? $infoCode->email : 'N/A',
                        'code_ref' => !empty($infoCode->code_ref) ? $infoCode->code_ref : null,
                    ],
                ];
            } else {
                $cupon = Client::verifyCodeCupon($code_ref);
                if ($cupon) {

                    $response = [
                        'success' => true,
                        'data' => [
                            'type_code' => "CUPON",
                            'dni' => null,
                            'client' => null,
                            'phone' => null,
                            'email' => null,
                            'code_ref' => $code_ref,
                        ],
                    ];
                } else {
                    $response = [
                        'success' => false,
                        'data' => [
                            'cod_err' => 'CODE_REF_NOT_CLIENT',
                            'msg' => "El codigo de referido no esta registrado en el sistema",
                        ],
                    ];
                }
            }
        }
        //Finalizando log
        LogApiV2::finishLog(
            $log,
            $response,
            0,
            $response['success'] ? 'D' : 'E',
            !$response['success'] ? $response['data']['msg'] : ''
        );

        return response()->json($response);
    }
}
