<?php

namespace App\Http\Controllers\Fiber;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Utilities\Common;
use App\Models\Client;
use App\Models\{FiberCityZone, Verify_contact_client, Sms_notification_token, HistorySmsFiber, HistoryMailFiber, ClientNetwey};
use Illuminate\Support\Facades\Validator;
use App\Utilities\Altan;
use DateTime;
use Log;

class ClientController extends Controller
{
    public function findClient(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'search' => 'required',
        ]);

        if ($validator->fails()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validator->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }

        $search =  $request->search;

        $clients = Client::searchClients($search, 20);

        $data = ["clients" => $clients];

        return Common::baseResponse(true, "Clientes obtenidos correctamente", $data, 200);
    }

    public function getClient(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'dni' => 'required',
        ]);

        if ($validator->fails()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validator->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }

        $client = Client::getFiberClientByDNI($request->dni);

        $data = $this->_getClient($request, $client);

        $data = ["client" => $data];

        return Common::baseResponse(true, "Cliente obtenido correctamente", $data, 200);
    }

    public function _getClient($request, $client){
        if(empty($client)){
            $errors = [
                "error_code" => "client_not_found",
                "errors" => [
                    "client" => ["Client not found"]
                ]
            ];
            return Common::baseResponse(true, "Cliente no encontrado", [], 200);
        }


        $client->status = true;

        if (!empty($client->phone_home)) {
            $chekingPhone = Client::verifyPhones($request->dni, $client->phone_home, $client->phone);
            // Log::info('chekingPhone ' . (String) json_encode($chekingPhone));

            if ($chekingPhone['success']) {
                $client->phone_fail = 'OK'; //No tiene fallo ningun telefono del cliente
                $client->phone_fail_obs = "";

            } else {
                $client->phone_fail = 'FAIL';
                $client->phone_fail_obs = $chekingPhone['msg'];
            }
        } else {
            $client->phone_fail = 'EMPTY';
            $client->phone_fail_obs = "Telefono principal del cliente es requerido para distintos procesos informativos y de verificacion de la venta";
        }

        $client->is_verify_phone = "";
        if ($client->phone_fail == 'OK') {
            if (!empty($client->verify_phone_id)) {
                //Se evalua si se tiene verify_phone_id que significa que tiene verificado el celular principal
                $codePhone = Verify_contact_client::getRegisterVerify($client->verify_phone_id);
                if (!empty($codePhone)) {
                    $client->is_verify_phone = $codePhone->status;
                }
            }
        }

        $client->mail_fail = 'OK'; //Email con formato correcto
        $client->mail_fail_obs = "";

        if (!empty($client->email)) {
            //Posee email se evalua que sea valido

            $chekinMail = Client::verifyMail($request->dni, $client->email);

            if (!$chekinMail['success']) {
                $client->mail_fail = 'FAIL';
                $client->mail_fail_obs = $chekinMail['msg'];
            }
        } else {
            //No tiene correo de contacto, se requiere
            $client->mail_fail = 'EMPTY';
            $client->mail_fail_obs = "El cliente no posee un correo registrado.";
        }
        return $client;
    }

    public function createClient(Request $request)
    {
        $inputs = $request->all();
        $obj = new \stdClass;
        $status = 200;
        $data = [];
        $message = "";


        $validator = Validator::make($inputs, [
            'name' => 'required',
            'last_name' => 'required',
            'phone' => 'required',
        ]);

        if ($validator->fails()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validator->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }
        $obj = $this->_registerLeaflet($inputs);
        if ($obj->error) {
            $status = 400;
            $message = $obj->message;
            $data = [
                "error_code" => "validation_error",
                "errors" => [
                    "client" => [$obj->message]
                ]
            ];
        } else {
            $message = "Prospecto registrado exitosamente.";
            unset($obj->error);
            unset($obj->message);
            $data = [
                "client" => $obj,
            ];
        }


        return Common::baseResponse($status == 200 ? true : false, $message, $data, $status);
    }

    public function _registerLeaflet($inputs = false)
    {
        $obj = new \stdClass;
        $obj->error = true;
        /* check this hasPermit */
        if ($inputs && hasPermit('RCL-DSE')) {
        $dateInput = null;
        if (!empty($inputs['birthday'])) {
            if (preg_match("/^(0[1-9]|[1-2][0-9]|3[0-1])-(0[1-9]|1[0-2])-[0-9]{4}$/", $inputs['birthday'])) {
            $newDate = new DateTime($inputs['birthday']);
            $dateInput = $newDate->format('Y-m-d');
            } else {
            $obj->message = 'Formato de fecha erroneo.';
            return $obj;
            }
        }

        if (!empty($inputs['email'])) {
            $chekinMail = Client::verifyMail(false, $inputs['email']);
            if (!$chekinMail['success']) {
            $obj->message = $chekinMail['msg'];
            return $obj;
            }
        }

        if (!empty($inputs['phone'])) {
            $chekingPhone = Client::verifyPhones(false, $inputs['phone'], '');
            if (!$chekingPhone['success']) {
            $obj->message = $chekingPhone['msg'];
            return $obj;
            }
        }

        if (!empty($inputs['phone2'])) {
            $chekingPhone = Client::verifyPhones(false, '', $inputs['phone2']);
            if (!$chekingPhone['success']) {
            $obj->message = $chekingPhone['msg'];
            return $obj;
            }
        }

        if (!empty($inputs['phone']) && !empty($inputs['phone2'])) {
            if ($inputs['phone'] == $inputs['phone2']) {
            $obj->message = "El telefono principal no puede ser el mismo telefono secundario!";
            return $obj;
            }
        }

        if (empty($inputs['dni'])) {
            $inputs['dni'] = uniqid();
        } else {
            $chekingDNI = Client::getFiberClientByDNI($inputs['dni']);
            if (!empty($chekingDNI)) {
            $obj->message = "INE ya esta siendo usado por otro cliente";
            return $obj;
            }
        }

        if (!empty($inputs['direction'])) {
            $simbol = array(" ,", "'", '"');
            $inputs['direction'] = str_replace($simbol, "", $inputs['direction']);
        }

        $data = [
            'dni' => $inputs['dni'],
            'name' => Common::normaliza($inputs['name']),
            'last_name' => Common::normaliza($inputs['last_name']),
            'address' => $inputs['direction'],
            'birthday' => $dateInput,
            'email' => $inputs['email'],
            'phone_home' => $inputs['phone'],
            'phone' => (($inputs['phone2']) ? $inputs['phone2'] : null),
            'social' => $inputs['social'],
            'date_reg' => date("Y-m-d H:i:s"),
            'reg_email' => session('user'),
        ];

        if ($inputs['social'] == 'S' && !empty($inputs['campaign'])) {
            $data['campaign'] = $inputs['campaign'];
        }

        if (!empty($inputs['lat']) && !empty($inputs['lon'])) {
            $data['lat'] = $inputs['lat'];
            $data['lng'] = $inputs['lon'];
        }

        if (!empty($inputs['note'])) {
            $data['note'] = $inputs['note'];
        }

        if (!empty($inputs['next_contact'])) {
            $newDate = new DateTime($inputs['next_contact']);
            $data['contact_date'] = $newDate->format('Y-m-d H:i:s');
        }

        //validando si es vendedor para asignarle el cliente
        if (session('user_type') == 'vendor') {
            $data['user_mail'] = session('user');
        }

        $client = Client::getClientINEorDN($inputs['dni'], $inputs['phone'], $inputs['email']);

        if (empty($client)) {
            Client::getConnect('W')->insert($data);

            $obj->dni = $inputs['dni'];
            $obj->phone = $inputs['phone'];
            $obj->name = Common::normaliza($inputs['name']);
            $obj->last_name = Common::normaliza($inputs['last_name']);
            $obj->error = false;
            $obj->message = 'Prospecto registrado exitosamente.';
        } else {
            $msg = 'El o los siguiente(s) dato(s),';
            if (!empty($client->email) && $client->email == $inputs['email']) {
            $msg .= ' email,';
            }

            if ($client->phone_home == $inputs['phone']) {
            $msg .= ' teléfono 1,';
            }

            if ($client->dni == $inputs['dni']) {
            $msg .= ' INE,';
            }

            $msg .= ' ya se encuentra(n) registrado(s).';

            $obj->message = $msg;
        }
        }

        return $obj;
    }

    public function updateClient(Request $request)
    {
        $input = $request->all();

        $validator = Validator::make($input, [
            'name' => 'required',
            'last_name' => 'required',
            'phone' => 'required',
            'dni' => 'required'
        ]);

        if ($validator->fails()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validator->errors()
            ];
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validator->errors()
            ];
            $first_error =  $validator->errors()->first();
            return Common::baseResponse(false, $first_error, $errors, 400);
        }

        $client = Client::getClientINEorDN($input['dni']);



        if(empty($client)){
            return Common::baseResponse(false, "Cliente no encontrado", [
                "error_code" => "client_not_found",
                "errors" => [
                    "client" => ["Client not found"]
                ]
            ], 400);
        }


        $phoneSecundary = (isset($input['phone2']) && !empty($input['phone2'])) ? $input['phone2'] : "";

        $autorizePhone = Client::isPermitUpdatePhone($input['dni'], $input['phone'], $phoneSecundary);

        $autorizeMail = Client::isPermitUpdateMail($input['dni'], $input['email']);
        $errm = '';

        if (!$autorizePhone['success']) {
            $errm .= $autorizePhone['msg'];
        }

        if (!$autorizeMail['success']) {
            $errm .= (!empty($errm)) ? " - " . $autorizeMail['msg'] : $autorizeMail['msg'];
        }

        if (!empty($errm)) {

            return Common::baseResponse(false, $errm, [
                "error_code" => "validation_error",
                "errors" => [
                    "client" => [$errm]
                ]
            ], 400);

        }

        $data = [
            'name' => $input['name'],
            'last_name' => $input['last_name'],
            'phone_home' => $input['phone'],
        ];

        $data['phone'] = $input['phone2'];


        if (!empty($input['email'])) {
            $data['email'] = $input['email'];
        }

        if (!empty($input['address'])) {
            $data['address'] = $input['address'];
        }

        Client::getConnect('W')->where('dni', $input['dni'])
                                ->update($data);

        sleep(1);

        $client = Client::getFiberClientByDNI($input['dni']);

        $client = $this->_getClient($request, $client);

        $data = ["client" => $client];

        return Common::baseResponse(true, "Cliente actualizado correctamente", $data, 200);

    }

    /**
     * [cantToken Evalua cuantos intentos de verificacion posee el telefono con el prospecto en el dia]
     * @param  Request $request [description]
     * @return [type]           [description]
    */

	public function cantToken(Request $request) {
        $response = ['success' => false, 'title' => "No se pudo revisar los registros de verificacion para el celular", 'msg' => "Faltan datos", 'icon' => "error", 'code' => 'ERR_DAT'];
        ///New validate
        $messages = [
            'phoneVal.required' => 'El telefono a verificar es requerido (IVF5694)',
            'phoneVal.regex' => 'El telefono a verificar no cumple el criterio de ser un valor valido (IVF5695)',
            'clientId.required' => 'El ID del prospecto es requerido (IVF5696)',
            'olt.required' => 'El ID de la OLT es requerido (IVF5697)',
            'city.required' => 'El ID de la ciudad es requerido (IVF5698)',
        ];
        $requisitos = [
            'phoneVal' => array(
                'required',
                'regex:/(^[0-9]{10}$)/u',
            ),
            'clientId' => array(
                'required',
            ),
            'olt' => array(
                'required',
            ),
            'city' => array(
                'required',
            ),
        ];

        $validate = Validator::make($request->all(), $requisitos, $messages);
        $errors = $validate->errors();

        if ($errors->any()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validate->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }

        //Se revisa si la olt y la ciudad amerita tokenizado celular
        $istokenizado = FiberCityZone::isCityZoneTokenizado($request->olt, $request->city);

        if ($istokenizado) {

            $chekingPhone = Client::verifyPhones($request->clientId, $request->phoneVal, '');
            if (!$chekingPhone['success']) {
                /* $response = ['success' => false, 'title' => "El teléfono ingresado requiere atención", 'msg' => $chekingPhone['msg'], 'icon' => "warning", 'code' => $chekingPhone['code']]; */
                
                return Common::baseResponse(false, "Error en los datos enviados", [
                    "error_code" => $chekingPhone['code'],
                    "errors" => [
                        "client" => [$chekingPhone['msg']]
                    ]
                ], 400);
            }

            //Revisamos que el telefono no halla sido verificado con otro usuario previamente
            $existVerifyOther = Verify_contact_client::isVerifyLasted($request->phoneVal, $request->clientId);
            if ($existVerifyOther) {
               /*  $response = ['success' => false, 'title' => "El teléfono ingresado requiere atención", 'msg' => "No se puede verificar el numero " . $request->phoneVal . ", ya fue usado en un proceso de verificación de otro prospecto!", 'icon' => "warning", 'code' => 'VRF_NOT']; */
                

                return Common::baseResponse(false, "Error en los datos enviados", [
                    "error_code" => "VRF_NOT",
                    "errors" => [
                        "client" => ["No se puede verificar el numero " . $request->phoneVal . ", ya fue usado en un proceso de verificación de otro prospecto!"]
                    ]
                ], 400);
            }

            //Revisamos si tiene registro de verificacion con el telefono que se envia
            $datClient = Client::getClientByDNI($request->clientId);
            $isVerifyPhone = "";
            $mailVerify = "";

            $verifyActive = new \stdClass;

            if (!empty($datClient)) {
                if (!empty($datClient->verify_phone_id)) {
                    $codePhone = Verify_contact_client::getRegisterVerify($datClient->verify_phone_id);
                    if (!empty($codePhone) && $datClient->phone_home == $request->phoneVal) {
                        $isVerifyPhone = $codePhone->status;
                        $verifyActive->id = $codePhone->id;
                        $verifyActive->platform = $codePhone->platform;
                    }
                }
                if (!empty($datClient->email)) {
                    $mailVerify = $datClient->email;
                }
            }

            //Los procesos de verificacion lo mantendremos vigentes por 24 horas, luego de pasado ese tiempo puede volver intentar el ciclo de 3 sms y 2 correos.

            $isPendingUsed = Verify_contact_client::getLastVerified($request->phoneVal, $request->clientId);
            $typeVerifySend = new \stdClass;
            $typeVerifySend->type = "SMS";
            $typeVerifySend->nextType = "SMS";
            $typeVerifySend->intento = 0;
            $typeVerifySend->email = $mailVerify;
            $typeVerifySend->phone = $request->phoneVal;
            $typeVerifySend->verify_id = null;

            if (!empty($isPendingUsed)) {
                $typeVerifySend->verify_id = $isPendingUsed->id;
                $typeVerifySend->type = $isPendingUsed->platform;

                $infoInten = Verify_contact_client::getRegisterVerify($isPendingUsed->id);
                if (!empty($infoInten)) {
                    $typeVerifySend->intento = $infoInten->tried;
                }

                //Si queremos que los 3 y 2 intentos sean perpetuos se debera sacar este bloque del if
                if ($typeVerifySend->type == "SMS" &&
                    $typeVerifySend->intento == 3) {
                    $typeVerifySend->nextType = "MAIL";
                } elseif ($typeVerifySend->type == "MAIL" &&
                    $typeVerifySend->intento == 2) {
                    $typeVerifySend->nextType = "CONTROL";
                } else {
                    $typeVerifySend->nextType = $typeVerifySend->type;
                }
                //end banderas para el siguiente modo de verificacion, si queremos sea perpetuo se debe sacar y poner fuera del cierre de llaves que sigue
            }

            //Deberia analizar si se agoto los 3 intento deberia enviar el codigo via correo
            $mailVerifySend = new \stdClass;
            $mailVerifySend->code = "NOT";
            $mailVerifySend->msg = "No es necesario envia aun el email con el codigo";
            $mailVerifySend->email = $mailVerify;

            //el cliente debe tener correo
            if ($typeVerifySend->nextType == "MAIL") {
                if (!empty($mailVerify)) {
                    $VerifyMail = Client::verifyMail($request->clientId, $mailVerify);
                    $mailVerifySend->code = $VerifyMail['code'];
                    $mailVerifySend->msg = $VerifyMail['msg'];
                } else {
                    $mailVerifySend->code = "EMP_MAIL";
                    $mailVerifySend->msg = "Es necesario que el prospecto cuente con un email para activar el metodo alterno de envio de Token NIP";
                }
            }

            /*
            $typeVerifySend->intento = Verify_contact_client::getRegisterVerifyInDay($request->phoneVal, $request->clientId);*/

           /*  $response = ['success' => true, 'title' => "Cantidad de verificacion del telefono con el mismo cliente", 'msg' => "Registros de intento de verificacion", 'icon' => "success", 'code' => $isVerifyPhone, 'use_mail' => $mailVerifySend, 'typeVerifySend' => $typeVerifySend, 'verifyActive' => $verifyActive]; */

            return Common::baseResponse(true, "Cantidad de verificacion del telefono con el mismo cliente", [
                'icon' => "success", 'code' => $isVerifyPhone, 'use_mail' => $mailVerifySend, 'typeVerifySend' => $typeVerifySend, 'verifyActive' => $verifyActive
            ], 200);

        } else {
            $response = ['success' => false, 'title' => "Verificacion de telefono no requerida", 'msg' => "La ciudad de la olt donde se agenda la cita no amerita verificacion", 'icon' => "success", 'code' => "NO_REQUIRED_VERIFY"];

            return Common::baseResponse(false, "Verificacion de telefono no requerida", [
                "error_code" => "NO_REQUIRED_VERIFY",
                "errors" => [
                    "client" => ["La ciudad de la olt donde se agenda la cita no amerita verificacion"]
                ]
            ], 400);
        }
	}

    public function newToken(Request $request) {
		
        $response = ['success' => false, 'title' => "No se pudo generar el nuevo token de verificación celular", 'msg' => "Faltan datos", 'icon' => "error", 'code' => 'ERR_DAT'];
        ///New validate
        $messages = [
            'phoneVal.required' => 'El telefono a verificar es requerido (IVF5486)',
            'phoneVal.regex' => 'El telefono a verificar no cumple el criterio de ser un valor valido (IVF5487)',
            'clientId.required' => 'El ID del prospecto es requerido (IVF5488)',
        ];
        $requisitos = [
            'phoneVal' => array(
                'required',
                'regex:/(^[0-9]{10}$)/u',
            ),
            'clientId' => array(
                'required',
            ),
        ];

        $validate = Validator::make($request->all(), $requisitos, $messages);
        $errors = $validate->errors();

        if ($errors->any()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validate->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }
        //verificamos el dni del prospecto y el telefono a verificar antes de crear el token
        $vericatePhone = Verify_contact_client::getCodeVerifyByPhone($request->phoneVal, $request->clientId);

        if ($vericatePhone['code'] != 'REJECTED' &&
            $vericatePhone['code'] != 'IS_PHONE_CLIENT' &&
            $vericatePhone['code'] != 'IS_PHONE_USER'
        ) {
            $obs = Verify_contact_client::getMsgVerify($vericatePhone['code']);

            //Obtengo el nombre para personalizar el mensaje
            $datClient = Client::getClientByDNI($request->clientId);
            $userText = "";
            $mailSend = "";
            if (!empty($datClient)) {
                if (!empty($datClient->name)) {
                    $nombre = explode(" ", $datClient->name)[0];
                    $userText = "Sr(a) " . $nombre . ", ";
                }
                if (!empty($datClient->email)) {
                    $mailSend = $datClient->email;
                }
            }

            $typeVerifySend = new \stdClass;
            $typeVerifySend->type = "SMS";
            $typeVerifySend->nextType = "SMS";
            $typeVerifySend->intento = 1;
            $typeVerifySend->email = $mailSend;
            $typeVerifySend->phone = $datClient->phone_home;

            //Reviso si tengo token pendientes por usar
            $isPendingUsed = Verify_contact_client::getLastVerified($request->phoneVal, $request->clientId);

            if (!empty($isPendingUsed)) {
                //Existen tokens de sms por usar
                $typeVerifySend->verify_id = $isPendingUsed->id;
                $typeVerifySend->type = $isPendingUsed->platform;
                $typeVerifySend->intento = $isPendingUsed->tried + 1;

                if ($typeVerifySend->type == "SMS" && $typeVerifySend->intento <= 3) {
                    //Envio de token por sms son 3
                    if ($typeVerifySend->intento == 3) {
                        $typeVerifySend->nextType = "MAIL";
                    } else {
                        $typeVerifySend->nextType = "SMS";
                    }
                    //Hay tokenes para el celular pendientes por usar,
                    //Se suma el intento de envio
                    $addsend = Verify_contact_client::addSendVerify($isPendingUsed->id);

                    if ($addsend['success']) {
                        $newToken = $isPendingUsed->token_verify;

                        $response['success'] = true;
                        $response['title'] = "Token de verificación SMS vigente";
                        $response['msg'] = "OK";
                        $response['icon'] = "success";
                        $response['code'] = "OK";
                        $response['token'] = $newToken;

                    } else {
                        $response = $addsend;
                    }
                } else {
                    //Envio por correo
                    //Genero un token nuevo para enviar por correo
                    if ($typeVerifySend->type == "SMS") {

                        if (!empty($mailSend)) {
                            $typeVerifySend->type = "MAIL";
                            $typeVerifySend->nextType = "MAIL";
                            $typeVerifySend->intento = 1;

                            //Marco en T las verificacion MAIL vencidas
                            Verify_contact_client::deleteOldVerified($request->phoneVal, $request->clientId, ["VERIFIED"], ['CREATE'], ['MAIL']);

                            $newToken = Common::getTokenVerify();
                            $response = Verify_contact_client::registerNewToken($request->phoneVal, $request->clientId, $newToken, $obs, $typeVerifySend->type, $mailSend);
                            $typeVerifySend->verify_id = $response['verify_id'];
                        } else {
                            $response['success'] = false;
                            $response['title'] = "Se requiere un correo para continuar";
                            $response['msg'] = "Es necesario que el prospecto cuente con un email para el envio del Token NIP.";
                            $response['icon'] = "warning";
                            $response['code'] = "EMP_MAIL";
                        }
                    } else {
                        //Envio por correo son 2
                        if ($typeVerifySend->intento <= 2) {
                            if ($typeVerifySend->intento == 2) {
                                $typeVerifySend->nextType = "CONTROL";
                            } else {
                                $typeVerifySend->nextType = "MAIL";
                            }
                            $addsend = Verify_contact_client::addSendVerify($isPendingUsed->id);
                            if ($addsend['success']) {
                                $newToken = $isPendingUsed->token_verify;

                                $response['success'] = true;
                                $response['title'] = "Token de verificación celular via email";
                                $response['msg'] = "OK";
                                $response['icon'] = "success";
                                $response['code'] = "OK";
                                $response['token'] = $newToken;

                            } else {
                                $response = $addsend;
                            }
                        } else {
                            //se debe autorizar por mesa
                            $typeVerifySend->type = "CONTROL";
                            $typeVerifySend->nextType = "CONTROL";
                            $response['success'] = true;
                            $response['title'] = "Mesa de control debe autorizar";
                            $response['msg'] = "OK";
                            $response['icon'] = "success";
                            $response['code'] = "OK";
                            $response['token'] = null;
                        }
                    }
                }
            } else {
                //Marco en T las verificacion SMS vencidas
                Verify_contact_client::deleteOldVerified($request->phoneVal, $request->clientId);

                //Creo un nuevo token sms
                $newToken = Common::getTokenVerify();
                $response = Verify_contact_client::registerNewToken($request->phoneVal, $request->clientId, $newToken, $obs);
                $typeVerifySend->verify_id = $response['verify_id'];
            }

            if ($response['success']) {

                $response['typeVerifySend'] = $typeVerifySend;

                if ($typeVerifySend->type == "SMS") {
                    //Envio el mensaje con el codigo de token
                    //NOTA: el sms_type debe ser 'G' y el mensaje debe ir en sms_attribute y en sms(En ambos el mismo contenido)
                    $msgNewToken = $userText . "Su token NIP de verificacion celular es: '" . $newToken . "' Nota: guarda este token ya que sera solicitado en distintos procesos";

                    try {
                        $smsSend = Sms_notification_token::Send_sms(
                            $request->phoneVal,
                            $request->phoneVal,
                            'G',
                            '1',
                            "Tokenizado de verificacion",
                            $msgNewToken,
                            $msgNewToken);

                        if ($smsSend) {
                            $dataH = ['sms_nip_id' => $smsSend,
                                'dni_client' => $request->clientId,
                                'process' => "TOKEN",
                                'phone_sms' => $request->phoneVal];
                            HistorySmsFiber::newHistorySMSFiber($dataH);
                        }

                    } catch (Exception $e) {
                        Log::error('No se pudo enviar el msj de tokenizado de telefono del prospecto: ' . $request->phoneVal . ' Error: ' . (String) json_encode($e->getMessage()));
                    }
                } elseif ($typeVerifySend->type == "MAIL") {
                    if (!empty($mailSend)) {
                        $infodata['user'] = $userText;
                        $infodata['token'] = $newToken;
                        try {
                            Mail::to($mailSend)->send(new SendTokenVerify($infodata));

                            $dataM = [
                                'email_client' => $mailSend,
                                'dni_client' => $request->clientId,
                                'process' => "TOKEN",
                                'data_send' => json_encode($infodata)];
                            HistoryMailFiber::newHistoryMailFiber($dataM);
                        } catch (Exception $e) {
                            Log::error("No se pudo enviar el correo a " . $mailSend . " con el codigo de tokenizacion celular del prospecto: " . $request->clientId . " Error: " . (String) json_encode($e->getMessage()));
                        }
                    } else {
                        Log::alert("El cliente " . $request->clientId . " requiere correo para el envio del token de verificación celular");
                    }
                } else {
                    //Se debe pedir autorizacion
                }
            }
        } else {
            $response['msg'] = $vericatePhone['msg'];
            $response['code'] = "NOT_PERMIT";
        }

        $data = $response;
        $data["token"] = $newToken ?? null;
        unset($data['success']);

        if($response['success'] == 200){
            return Common::baseResponse($response['success'], $response['title'], $data, 200);

        }else{
            return Common::baseResponse($response['success'], $response['title'], [
                "error_code" => $response['code'],
                "errors" => [
                    "client" => [$response['msg']]
                ],
                ...$data
            ], 400);
        }

	}

    /**
 * [verifyPhone Se envio el token para confirmar el celular]
 * @param  Request $request [description]
 * @return [type]           [description]
 */
	public function verifyPhone(Request $request) {
		
        $response = ['success' => false, 'title' => "No se pudo verificar el numero celular", 'msg' => "Faltan datos", 'icon' => "error", 'code' => 'ERR_DAT'];
        ///New validate
        $messages = [
            'phoneVal.required' => 'El telefono a verificar es requerido (IVF5565)',
            'phoneVal.regex' => 'El telefono a verificar no cumple el criterio de ser un valor valido (IVF5566)',
            'clientId.required' => 'El ID del prospecto es requerido (IVF5567)',
            'tokenPhone.required' => 'El token a verificar es requerido (IVF5568)',
            'tokenPhone.regex' => 'El token a verificar no cumple el criterio de ser un valor valido (IVF5569)',
        ];
        $requisitos = [
            'phoneVal' => array(
                'required',
                'regex:/(^[0-9]{10}$)/u',
            ),
            'clientId' => array(
                'required',
            ),
            'tokenPhone' => array(
                'required',
                'regex:/(^[0-9]{4}$)/u',
                // 'regex:/(^[a-zA-Z]{3}[0-9]{3}$)/u',
            ),
        ];

        $validate = Validator::make($request->all(), $requisitos, $messages);
        $errors = $validate->errors();

        if ($errors->any()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validate->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }

        //Si el cliente envia telefono secundario y este posee ya una verificacion previa capturo el valor antes de sobre-escribirlo
        $verify_previo = false;
        $newPhoneSecondary = "";
        //if (!empty($request->phoneSecondary)) {
        $dataClient = Client::getClientByDNI($request->clientId);
        if (!empty($dataClient)) {
            if (!empty($dataClient->verify_phone_id)) {
                $dataVerify = Verify_contact_client::getRegisterVerify($dataClient->verify_phone_id);
                if (!empty($dataVerify)) {
                    if ($dataVerify->status == "VERIFIED") {
                        $verify_previo = $dataClient->verify_phone_id;
                        $newPhoneSecondary = $dataClient->phone_home;
                    }
                }
            }
        }
        //}

        //cadena valida 1234
        $request->tokenPhone = strtoupper($request->tokenPhone);
        $resulVery = Verify_contact_client::verifyToken($request->phoneVal, $request->clientId, $request->tokenPhone);
        $response = $resulVery;

        if ($resulVery['success']) {
            //Se verifico el cel
            $response['icon'] = Verify_contact_client::getIconVerified('VERIFIED') . $response['msg'];

            //El telefono secondario no es necesario, se llega se guarda
            if (!empty($newPhoneSecondary)) {
                Client::updatePhoneSecondary($request->clientId, $newPhoneSecondary, $verify_previo);
            }
        } else {
            //No se ha logrado verificar
            $response['icon'] = Verify_contact_client::getIconVerified('NOT_VERIFIED') . $response['msg'];
        }
        $data = $response;
        
        unset($data['success']);

        if($response['success'] == 200){
            return Common::baseResponse($response['success'], $response['title'], $data, $response['success'] ? 200 : 200);

        }


        /* ...$data lo que hace es que si $data es un array, lo descompone en sus elementos y los pasa como argumentos a la función, ejemplo: 
        $data = ["status", "code", "data"];
        return Common::baseResponse($response['success'], $response['title'], [
            "error_code" => $response['code'],
            "errors" => [
                "client" => [$response['msg']]
            ],
            $data[0],
            $data[1],
            $data[2]
        ], 400); 
        */
        return Common::baseResponse($response['success'], $response['title'], [
            "error_code" => $response['code'],
            "errors" => [
                "client" => [$response['msg']]
            ],
            ...$data
        ], 400);
    
	}


    public function clientGetByDN(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'msisdn' => 'required',
        ]);

        if ($validator->fails()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validator->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }

        $msisdn = $request->msisdn;

        $client = ClientNetwey::getClientByDN($msisdn);

        if ($client) {
            $data = ["client" => $client];
            return Common::baseResponse(true, "Cliente encontrado", $data, 200);
        } 
        
        return Common::baseResponse(false, "Cliente no encontrado", [
            "error_code" => "client_not_found",
            "errors" => [
                "client" => ["Cliente no encontrado"]
            ]
        ], 400);
    
        
        
    }


    public function validImei(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'imei' => 'required',
        ]);

        if ($validator->fails()) {
            $errors = [
                "error_code" => "validation_error",
                "errors" => $validator->errors()
            ];
            return Common::baseResponse(false, "Error en los datos enviados", $errors, 400);
        }

        if (!empty($request->imei)) {
            $res = Altan::validIMEI($request->imei);

            if ($res['success']) {
                #return response()->json(['error' => false, 'data' => $res['data']]);
                return Common::baseResponse(true, "IMEI valido", $res['data'], 200);
            }
        }

        return Common::baseResponse(false, "IMEI no valido", [
            "error_code" => "imei_not_valid",
            "errors" => [
                "imei" => ["IMEI no valido"]
            ]
        ], 400);
        

    }


}
