<?php

namespace App\Http\Controllers;

//Otras clases
use App\Mail\BuyOKSend;
use App\Mail\BuyOKV2;
use App\Mail\Referred_email_confirm;
use App\Mail\Referred_congratulations;
use App\Models\Articles;
use App\Models\Client;
//use App\Utilities\SendMail;
use App\Models\DeferredPayment;
use App\Models\IpnNotification;
use App\Models\LogApiV2;
use App\Models\MercadoPago;
use App\Models\MercadoPagoError;
use App\Models\MPLog;
use App\Models\NinetyNineMinutes;

//Modelos
use App\Models\Ordens;
use App\Models\OrdensDetail;
use App\Models\OrdensStatus;
use App\Models\ProvaDelivery;
use App\Models\ServiciabilityBuy;
use App\Models\TempCar;
use App\Models\TempCarDetail;
use App\Models\TokenApiSeller;
use App\Models\Transaction;
use App\Models\User;
use App\Models\VoyweyDelivery;
use App\Utilities\Common;
use App\Utilities\CustomLogs;
use App\Utilities\Jelou;
use App\Utilities\MercadoPagoCus;
use App\Utilities\NinetyNineMin;
use App\Utilities\prova;
use App\Utilities\voywey;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;

use Log;

class PayController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /*
  Retorna html para poder hacer un pago por medio de mercado pago
   */
    public function getPaymentUrl(Request $request, $transaction = false, $publicToken = false)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        $response = [
            'success' => false,
            'data' => ['cod_err' => 'ERR_PARAM', 'msg' => 'Faltan parámetros.'],
        ];

        //Se consulta las transacciones activas y cerradas para poder mostrar el mensaje de pago exitoso
        $token = TokenApiSeller::getInfTokenByPublicToken($publicToken);

        $transactionT = TempCar::getTransactionAP(
            $transaction,
            (!empty($token) && $token->use_pm_netwey == 'Y') ? $token->token : false
        );

        $transactionD = TempCarDetail::getTransactionDetailAP(
            $transaction,
            (!empty($token) && $token->use_pm_netwey == 'Y') ? $token->token : false
        );

        if (!empty($transactionT) && count($transactionD)) {
            $nine = NinetyNineMinutes::getActOrSendDelivery($transactionT->id);

            $prova = ProvaDelivery::getActOrSendDelivery($transactionT->id);

            $voywey = VoyweyDelivery::getActOrSendDelivery($transactionT->id);

            //Validando que la transaccion tenga tenga todos los datos necesarios
            if ((!empty($nine) || !empty($prova) || !empty($voywey)) && !empty($transactionT->client_dni)) {

                if (!empty($_SESSION['data'])) {
                    $data = $_SESSION['data'];
                    unset($_SESSION["data"]);
                }

                return view('payments.pay_mp', compact('transaction', 'data', 'transactionT', 'publicToken'));
            } else {
                $response['data']['cod_err'] = 'TR_NOTVALID';
                $response['data']['msg'] = 'Transacción no válida...';
            }
        } else {
            $response['data']['cod_err'] = 'TR_NOTVALID';
            $response['data']['msg'] = 'Transacción no válida....';
        }

        //Finalizando log
        LogApiV2::finishLog(
            $log,
            $response,
            0,
            $response['success'] ? 'D' : 'E',
            !$response['success'] ? $response['data']['msg'] : ''
        );

        return response()->json($response);
    }

    /*
  Procesa el pago por mercado pago
   */
    public function processPayment(Request $request)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        if ($request->isMethod('post')) {
            $resp = [
                'success' => false,
                'message' => 'No se pudo procesar la transacción',
            ];

            $inputs = $request->input();

            //Validando que vengan todos los campos
            if (
                !empty($inputs['transaction']) &&
                !empty($inputs['publicToken']) &&
                !empty($inputs['payerEmail']) &&
                !empty($inputs['payerAddress']) &&
                !empty($inputs['payerPostalCode']) &&
                !empty($inputs['token']) &&
                !empty($inputs['last_four_digits']) &&
                !empty($inputs['paymentMethodId'])
            ) {
                $token = TokenApiSeller::getInfTokenByPublicToken($inputs['publicToken']);

                $transactionT = TempCar::getTransaction(
                    $inputs['transaction'],
                    !empty($token) ? $token->token : false,
                    'W'
                );

                $transactionD = TempCarDetail::getTransactionDetail(
                    $inputs['transaction'],
                    !empty($token) ? $token->token : false
                );

                if (!empty($transactionT) && count($transactionD)) {

                    $nine = NinetyNineMinutes::getActiveDelivery($transactionT->id);

                    $prova = ProvaDelivery::getActiveDelivery($transactionT->id);

                    $voywey = VoyweyDelivery::getActiveDelivery($transactionT->id);

                    //Validando que la transaccion tenga tenga todos los datos necesarios
                    if ((!empty($nine) || !empty($prova) || !empty($voywey)) && !empty($transactionT->client_dni)) {
                        $inventaryValid = false;

                        if (!empty($nine)) {
                            //Validando inventario de 99 min
                            $inventaryValid = NinetyNineMin::validateInventory(
                                $transactionD->pluck('id_artic'),
                                $nine->postal_code,
                                $request,
                                $log
                            );

                            $currier = '99 minutos';
                        }

                        if (!empty($prova)) {
                            //Validando inventario de prova
                            $inventaryValid = prova::validateInventory(
                                $prova->deposit,
                                $transactionD->pluck('sku')->toArray(),
                                $log
                            );

                            $currier = 'Prova';
                        }

                        if (!empty($voywey)) {
                            //Validando inventario de voywey
                            $inventaryValid = voywey::validateInventory(
                                $voywey->postal_code,
                                $transactionD->pluck('sku')->toArray(),
                                $log
                            );

                            $currier = 'Voywey';
                        }

                        //NOTA: Si se agrega otro metodo de envio aqui se debe validar el inventario en ese metodo de envio
                        if ($inventaryValid) {
                            //Obteniendo detalle de los productos
                            $productsd = TempCarDetail::getProductsDetail(
                                $inputs['transaction'],
                                $token->token
                            );

                            //Monto total que debe pagar el cliente.
                            $total = $transactionT->price_sending;

                            $products[] = [
                                'id' => '001',
                                'title' => 'Envio',
                                'description' => $currier,
                                'category_id' => 'services',
                                'quantity' => 1,
                                'unit_price' => $transactionT->price_sending,
                            ];

                            foreach ($productsd as $productd) {
                                $total += $productd->price_pack;
                                $products[] = [
                                    'id' => $productd->id,
                                    'title' => $productd->title,
                                    'description' => $productd->service,
                                    'category_id' => 'services',
                                    'quantity' => 1,
                                    'unit_price' => $productd->price_pack,
                                ];
                            }

                            //Obteniendo datos del cliente
                            $clientD = Client::getClientByDni($transactionT->client_dni);

                            //Bandera para verficar que el pago se proceso por alguna plataforma
                            $isProcess = false;

                            $transactionId = uniqid('APISEL_') . time();

                            $data = [
                                'transaction_amount' => $total,
                                'token' => $inputs['token'],
                                'description' => implode(', ', $productsd->pluck('title')->toArray()),
                                'payment_method_id' => $inputs['paymentMethodId'],
                                'external_reference' => $transactionId,
                                'payer_email' => $inputs['payerEmail'],
                                'binary_mode' => true,
                                'notification_url' => '',
                                'additional_info' => [
                                    'payer' => [
                                        'first_name' => $clientD->name,
                                        'last_name' => $clientD->last_name,
                                        'phone' => [
                                            'area_code' => '52',
                                            'number' => $clientD->phone_home,
                                        ],
                                        'address' => [
                                            'street_name' => $inputs['payerAddress'],
                                            'zip_code' => $inputs['payerPostalCode'],
                                            'street_number' => '',
                                        ],
                                    ],
                                    'items' => $products,
                                    'shipments' => [
                                        'receiver_address' => [
                                            'zip_code' => $inputs['payerPostalCode'],
                                            'street_name' => $inputs['payerAddress'],
                                            'street_number' => '',
                                        ],
                                    ],
                                ],
                            ];

                            /*Log de mercado pago*/
                            $logmp = new MPLog;
                            $logmp->transaction = $transactionId;
                            $logmp->send = (string) json_encode($data);
                            $logmp->date_send = date('Y-m-d H:i:s');
                            $logmp->save();

                            $payment = MercadoPagoCus::doPay($data);

                            if ($payment) {
                                /*Log de mercado pago*/
                                $logmp->received = (string) json_encode($payment->toArray());
                                $logmp->date_received = date('Y-m-d H:i:s');
                                $logmp->save();

                                $mp = new MercadoPago;
                                $mp->status_recharge = "PE";
                                $mp->type = "S";
                                $mp->status = strtolower($payment->status);
                                $mp->unique_transaction = $transactionId;
                                $mp->service_id = $transactionT->id;
                                $mp->amount = $total;
                                $mp->mp_id = $payment->id;
                                $mp->token_card = $inputs['token'];
                                $mp->payment_method = $payment->payment_method_id;
                                $mp->date_approved = $payment->date_approved;
                                $mp->status_detail = $payment->status_detail;
                                $mp->last_four_digits = $inputs['last_four_digits'];
                                $mp->date_reg = date('Y-m-d H:i:s');
                                $mp->save();

                                if ($payment->status == "approved") {
                                    //Actualizando estatus a procesado
                                    $mp->status_recharge = "PR";

                                    $descStatus = 'Creado';
                                    $ordenStatus = '1';
                                    $referenceStatus = 0;
                                    $urlF = '';

                                    if (!empty($nine)) {
                                        $resnine = NinetyNineMin::generateDelivery(
                                            $transactionT->id,
                                            $inputs['transaction'],
                                            $token->token
                                        );

                                        if ($resnine['success']) {
                                            $dataOrden['ordNbr'] = $resnine['data']->order;
                                            $dataOrden['error_verify'] = 'OK';

                                            //$descStatus = 'Creado';
                                            //$ordenStatus = '1';
                                            $referenceStatus = $resnine['data']->order;
                                            $urlF = $resnine['data']->client_traking_url;
                                        } else {
                                            //Notificar a alguien porque no se creo el delivery en 99min y el pago se ejecuto
                                            $dataOrden['error_verify'] = 'ERROR';

                                            CustomLogs::addMessage(
                                                'Envío no procesado 99min (' . $transactionT->id . '): ' . json_encode($resnine),
                                                $log
                                            );

                                            CustomLogs::sendErrorDelMail('99min', $transactionT->id);
                                        }
                                    }

                                    if (!empty($prova)) {
                                        $resProva = prova::makeDelivery(
                                            $transactionT->id,
                                            $inputs['transaction']
                                        );

                                        if ($resProva['success']) {
                                            $dataOrden['ordNbr'] = $resProva['data']->folio;
                                            $dataOrden['error_verify'] = 'OK';

                                            //$descStatus = 'Creado';
                                            //$ordenStatus = '1';
                                            $referenceStatus = $resProva['data']->folio;
                                            $urlF = $resProva['data']->trakig_url;
                                        } else {
                                            //Notificar a alguien porque no se creo el delivery en Prova y el pago se ejecuto
                                            $dataOrden['error_verify'] = 'ERROR';

                                            CustomLogs::addMessage(
                                                'Envío no procesado Prova (' . $transactionT->id . '): ' . json_encode($resProva),
                                                $log
                                            );

                                            CustomLogs::sendErrorDelMail('Prova', $transactionT->id);
                                        }
                                    }

                                    if (!empty($voywey)) {
                                        $resVoywey = voywey::makeDelivery(
                                            $transactionT->id,
                                            $inputs['transaction']
                                        );

                                        if ($resVoywey['success']) {
                                            $dataOrden['ordNbr'] = $resVoywey['data']->folio;
                                            $dataOrden['error_verify'] = 'OK';

                                            $referenceStatus = $resVoywey['data']->folio;
                                            $urlF = $resVoywey['data']->trakig_url;
                                        } else {
                                            //Notificar a alguien porque no se creo el delivery en 99min y el pago se ejecuto
                                            $dataOrden['error_verify'] = 'ERROR';

                                            CustomLogs::addMessage(
                                                'Envío no procesado Voywey (' . $transactionT->id . '): ' . json_encode($resVoywey),
                                                $log
                                            );

                                            CustomLogs::sendErrorDelMail('Voywey', $transactionT->id);
                                        }
                                    }

                                    //NOTA: Si se agrega otro metodo de envío se debe agregar aqui.

                                    //Creando orden
                                    $dataOrden['totalAmount'] = $total;
                                    $dataOrden['dni'] = $transactionT->client_dni;
                                    $dataOrden['amount_delivery'] = $transactionT->price_sending;
                                    $dataOrden['pricedetail'] = $transactionD->sum('price_pack');

                                    //Buscando el email del vendedor relacionado con el concentrador
                                    $seller = User::getEmailByConc($token->concentrator_id);
                                    $dataOrden['seller_email'] = !empty($seller) ? $seller->email : 'buscar-correo';

                                    $orden = Ordens::createOrden($dataOrden);

                                    //agregando id de orden a merado pago
                                    $mp->order_id = $orden->id;
                                    $mp->save();

                                    //Creando detalle de orden
                                    foreach ($transactionD as $detail) {
                                        $serv = ServiciabilityBuy::getServiciability($detail->serviciability_id);

                                        $namesArt = '';
                                        $sku = Articles::getArticle($detail->id_artic);

                                        $namesArt .= $sku->title . ' ';
                                        $dataOD['artic'] = $detail->id_artic;
                                        $dataOD['serviceId'] = $detail->id_service;
                                        $dataOD['packPriceId'] = $detail->id_pack_price;
                                        $dataOD['dni'] = $transactionT->client_dni;
                                        $dataOD['sku'] = $sku->sku;
                                        $dataOD['pricedetail'] = $detail->price_pack;
                                        $dataOD['address'] = $serv->address;
                                        $dataOD['id_detail'] = $detail->id;

                                        if (!empty($serv->lat)) {
                                            $dataOD['lat'] = $serv->lat;
                                        }

                                        if (!empty($serv->lng)) {
                                            $dataOD['lng'] = $serv->lng;
                                        }

                                        if (!empty($serv->serviciability)) {
                                            $dataOD['serviciability'] = $serv->serviciability;
                                        }

                                        $ordenDetail = OrdensDetail::createDetail($dataOD, $orden);
                                    }

                                    //Insertando primer estatus
                                    OrdensStatus::insert([
                                        'id_ordens' => $orden->id,
                                        'description' => $descStatus,
                                        'status' => $ordenStatus,
                                        'date' => date('Y-m-d H:i:s'),
                                        'reference' => $referenceStatus,
                                        'send' => 'N',
                                    ]);

                                    //Cerrando transaccion
                                    $transactionT->status = 'P';
                                    $transactionT->save();

                                    $resp['success'] = true;

                                    //Enviando email de compra exitosa al cliente
                                    $data = [
                                        'amount' => $total,
                                        'concept' => implode(', ', $productsd->pluck('title')->toArray()),
                                        'urlFolow' => !empty($urlF) ? str_replace('\\', '', $urlF) : '',
                                        'urlRecibe' => env('URL_SITE') . 'tienda/descargar-recibo/' . $orden->id,
                                        'urlBuyStatus' => env('URL_SITE') . 'mi-netwey/estado-de-compra',
                                        'folio' => !empty($referenceStatus) ? $referenceStatus : '',
                                        'date' => date('Y-m-d H:i:s'),
                                    ];

                                    try {
                                        Mail::to([$inputs['payerEmail']])
                                            ->send(new BuyOKV2($data));
                                    } catch (\Exception $e) {
                                        CustomLogs::addMessage(
                                            'Correo de compra exitosa no enviado',
                                            $log
                                        );

                                        CustomLogs::registerLog(
                                            'error',
                                            'Correo de compra exitosa no enviado a ' . $inputs['payerEmail'] . ' Error: ' . $e->getMessage(),
                                            'F',
                                            $request,
                                            $res
                                        );
                                    }
                                }

                                $msg = MercadoPagoError::select('id', 'message')
                                    ->where('status_detail', $payment->status_detail)
                                    ->first();

                                if (!empty($msg)) {
                                    $message = str_replace('[amount]', $total, $msg->message);
                                    $message = str_replace('[payment_method_id]', $inputs['paymentMethodId'], $message);
                                    $message = str_replace('[installments]', '1', $message);
                                } else {
                                    $message = 'Sin mensaje.';
                                }

                                if (!empty($message)) {
                                    $resp['message'] = $message;
                                }

                                if ($token->send_ipn == 'Y' && !empty($token->ipn)) {
                                    $resIPN = [
                                        'transaction' => $inputs['transaction'],
                                        'pay_status' => ($payment->status == "approved") ? 'approved' : 'failed',
                                        'pay_id' => $transactionId,
                                        'message' => $message,
                                        'pay_status_detail' => $payment->status_detail,
                                        'date' => date('Y-m-d H:i:s'),
                                    ];

                                    //Notificar al ipn
                                    $respipn = Common::executeCurl($token->ipn, 'POST', [], $resIPN);

                                    IpnNotification::insert([
                                        'end_point' => $token->ipn,
                                        'transaction' => $inputs['transaction'],
                                        'unique_transaction' => $transactionId,
                                        'n_notification' => 1,
                                        'data' => (string) json_encode($resIPN),
                                        'response_code' => $respipn['code'],
                                        'date_reg' => date('Y-m-d H:i:s'),
                                        'status' => $respipn['code'] == 200 ? 'OK' : 'S',
                                    ]);
                                }
                            }
                        } else {
                            $resp['message'] = 'Se agoto el inventario del artículo seleccionado';

                            CustomLogs::addMessage(
                                'Se agoto el inventario del artículo seleccionado',
                                $log
                            );
                        }
                    } else {
                        CustomLogs::addMessage(
                            'No se consiguieron metodos de envío asignados',
                            $log
                        );
                    }
                }
            }

            $_SESSION['data'] = $resp;

            //Finalizando log
            LogApiV2::finishLog(
                $log,
                $resp,
                0,
                $resp['success'] ? 'D' : 'E',
                !$resp['success'] ? $resp['message'] : ''
            );

            return redirect()->route(
                'getPaymentUrl',
                [
                    'transaction' => $inputs['transaction'],
                    'publicToken' => $inputs['publicToken'],
                ]
            );
        }
    }

    /**
     * Registra el pago exitoso de una compra.
     *
     * @param Illuminate\Http\Request $request
     * @return Object
     */
    public function registerPayment(Request $request)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        $response = [
            'success' => false,
            'data' => ['cod_err' => 'ERR_PARAM', 'msg' => 'Faltan parámetros.'],
        ];

        $inputs = $request->input();

        if (
            !empty($inputs['transaction']) &&
            !empty($inputs['data_payment']) &&
            !empty($inputs['data_payment']['method'])
        ) {

            //Verificando si la transaccion es válida
            $transaction = TempCar::getTransaction(
                $inputs['transaction'],
                $request->bearerToken(),
                'W'
            );

            $transactionD = TempCarDetail::getTransactionDetail(
                $inputs['transaction'],
                $request->bearerToken()
            );

            $infToken = TokenApiSeller::getInfToken($request->bearerToken());

            if (!empty($transaction) && count($transactionD) && $infToken->use_pm_netwey == 'N') {
                //Validando que el usuario al que le quieren asignar la venta exista
                if (!empty($inputs['data_payment']['seller'])) {
                    $isVU = User::getUser($inputs['data_payment']['seller']);

                    if (empty($isVU) || $isVU->concentrator_id != $infToken->concentrator_id) {
                        $response['data']['cod_err'] = 'ERR_SELLER';
                        $response['data']['msg'] = 'El vendedor no existe.';

                        //Finalizando log
                        LogApiV2::finishLog(
                            $log,
                            $response,
                            0,
                            $response['success'] ? 'D' : 'E',
                            !$response['success'] ? $response['data']['msg'] : ''
                        );

                        return response()->json($response);
                    }
                }

                $nine = NinetyNineMinutes::getActiveDelivery($transaction->id);

                $prova = ProvaDelivery::getActiveDelivery($transaction->id);

                $voywey = VoyweyDelivery::getActiveDelivery($transaction->id);

                //Validando que la transaccion tenga tenga todos los datos necesarios
                if ((!empty($nine) || !empty($prova) || !empty($voywey)) && !empty($transaction->client_dni)) {
                    //Bandera para validar la existencia de inventario
                    $inventaryValid = false;

                    if (!empty($nine)) {
                        //Validando inventario de 99 min
                        $inventaryValid = NinetyNineMin::validateInventory(
                            $transactionD->pluck('id_artic'),
                            $nine->postal_code,
                            $request,
                            $log
                        );
                    }

                    if (!empty($prova)) {
                        //Validando inventario de prova
                        $inventaryValid = prova::validateInventory(
                            $prova->deposit,
                            $transactionD->pluck('sku')->toArray(),
                            $log
                        );
                    }

                    if (!empty($voywey)) {
                        //Validando inventario de voywey
                        $inventaryValid = voywey::validateInventory(
                            $voywey->postal_code,
                            $transactionD->pluck('sku')->toArray(),
                            $log
                        );
                    }

                    if ($inventaryValid) {
                        //Bandera para verficar que el pago se proceso por alguna plataforma
                        $isProcess = false;

                        //Monto total que debe pagar el cliente.
                        //Logica de cupones por ahora solo implementada para envio costo 0 modificar esta condición
                        //Si se necesita algo mas complejo
                        if (
                            $infToken->accept_coupon == 'Y' &&
                            !empty($inputs['data_payment']['coupon'])
                        ) {

                            $objCodeR = Client::getClientByCodeR(trim(
                                $inputs['data_payment']['coupon']
                            ));
                            //Es un cupon o un codigo de referido
                            $cupon = Client::verifyCodeCupon($inputs['data_payment']['coupon']);
                            if (!empty($objCodeR) || $cupon) {
                                $total = $transactionD->sum('price_pack');
                                $discount = $transaction->price_sending;
                            }
                        } else {
                            $total = $transaction->price_sending + $transactionD->sum('price_pack');
                        }

                        //Procesando pago de mercado pago
                        if (strtoupper($inputs['data_payment']['method']) == 'MP') {
                            if (!empty($inputs['data_payment']['id']) /*&&
            !empty($inputs['data_payment']['last_four_digits'])*/) {

                                //Validando que el pago sea correcto
                                $payment = MercadoPagoCus::getPayment($inputs['data_payment']['id']);

                                //Saltar validacion de mercado pago cuando el mismo link se uso en dos pagos diferentes
                                if (env('SALTAR_VAL_MP_DOBLE', false) == true) {
                                    $condicion = true;
                                } else {
                                    $condicion = ($payment->transaction_amount == $total
                                        && $payment->external_reference == $inputs['transaction']);
                                }

                                if (
                                    $payment
                                    && $payment->status
                                    && $payment->external_reference
                                    && $payment->date_approved
                                    && $payment->transaction_amount
                                    && $payment->card
                                    && $payment->status_detail
                                    && $payment->payment_method_id
                                    && $payment->status == 'approved'
                                    && $condicion
                                    // && $payment->card->last_four_digits == $inputs['data_payment']['last_four_digits']

                                ) {

                                    //Saltar validacion de mercado pago cuando el mismo link se uso en dos pagos diferentes
                                    if (env('SALTAR_VAL_MP_DOBLE', false) == false) {
                                        //Verificando si la referencia del pago ya fue usada en otra notificación
                                        $isUsed = MercadoPago::isUsed($inputs['data_payment']['id']);
                                    } else {
                                        $isUsed = null;
                                    }

                                    if (empty($isUsed)) {
                                        $mp = new MercadoPago;
                                        $mp->status_recharge = "PE";
                                        $mp->type = "S";
                                        $mp->status = $payment->status;
                                        $mp->unique_transaction = $payment->external_reference;
                                        $mp->service_id = $transaction->id;
                                        $mp->amount = $payment->transaction_amount;
                                        $mp->mp_id = $inputs['data_payment']['id'];
                                        $mp->payment_method = $payment->payment_method_id;
                                        $mp->date_approved = $payment->date_approved;
                                        $mp->status_detail = $payment->status_detail;
                                        //$mp->last_four_digits = $payment->card->last_four_digits;
                                        $mp->date_reg = date('Y-m-d H:i:s');
                                        $mp->save();

                                        $paymenM = $payment->payment_method_id;

                                        $isProcess = true;
                                    } else {
                                        $response['data']['cod_err'] = 'ERR_MP_DATA';
                                        $response['data']['msg'] = 'Fallo validacion del pago (1).';
                                    }
                                } else {
                                    $response['data']['cod_err'] = 'ERR_MP_DATA';
                                    $response['data']['msg'] = 'Fallo validacion del pago (2).';
                                }
                            } else {
                                $response['data']['cod_err'] = 'ERR_MP';
                                $response['data']['msg'] = 'Faltan parámetros de pago.';
                            }
                        }

                        if (strtoupper($inputs['data_payment']['method']) == 'DEFERRED' && $infToken->deferred == 'Y') {
                            if (!empty($inputs['data_payment']['id'])) {
                                $isUsed = DeferredPayment::getPayment($inputs['data_payment']['id']);

                                if (empty($isUsed)) {
                                    $date = date('Y-m-d H:i:s');
                                    $payment = new DeferredPayment;
                                    $payment->folio = $inputs['data_payment']['id'];
                                    $payment->transaction = $inputs['transaction'];
                                    $payment->amount = $total;
                                    $payment->type_payment = !empty($inputs['data_payment']['type_payment']) ? strtoupper($inputs['data_payment']['type_payment']) : null;
                                    $payment->date_reg = $date;
                                    $payment->date_update = $date;
                                    $payment->save();

                                    $paymenM = !empty($inputs['data_payment']['type_payment']) ? strtoupper($inputs['data_payment']['type_payment']) : false;

                                    $isProcess = true;
                                } else {
                                    $response['data']['cod_err'] = 'ERR_DEF_DATA';
                                    $response['data']['msg'] = 'Folio ya registrado.';
                                }
                            } else {
                                $response['data']['cod_err'] = 'ERR_DEF';
                                $response['data']['msg'] = 'Faltan parámetros de pago.';
                            }
                        }

                        //Agregar los nuevos metodos de pago de aqui para abajo

                        if ($isProcess) {
                            $descStatus = 'Creado';
                            $ordenStatus = '1';
                            $referenceStatus = 0;
                            $urlF = '';

                            //Actualizando estatus a procesado
                            if (strtoupper($inputs['data_payment']['method']) == 'MP') {
                                $mp->status_recharge = "PR";
                            }

                            if (strtoupper($inputs['data_payment']['method']) == 'DEFERRED') {
                                $descStatus = 'En espera de pago';
                                $ordenStatus = '-1';
                            }

                            //Generando envio por 99 min
                            if (!empty($nine)) {
                                $resnine = NinetyNineMin::generateDelivery(
                                    $transaction->id,
                                    $inputs['transaction'],
                                    $request->bearerToken()
                                );

                                $state = $nine->state;
                                $colony = $nine->neighborhood;
                                $currier = '99Min';

                                if ($resnine['success']) {
                                    $dataOrden['ordNbr'] = $resnine['data']->order;
                                    $dataOrden['error_verify'] = 'OK';

                                    $referenceStatus = $resnine['data']->order;
                                    $urlF = $resnine['data']->client_traking_url;
                                } else {
                                    //Notificar a alguien porque no se creo el delivery en 99min y el pago se ejecuto
                                    $dataOrden['error_verify'] = 'ERROR';

                                    CustomLogs::addMessage(
                                        'Envío no procesado 99min (' . $transaction->id . '): ' . json_encode($resnine),
                                        $log
                                    );

                                    CustomLogs::sendErrorDelMail('99min', $transaction->id);
                                }
                            }

                            if (!empty($prova)) {
                                $resProva = prova::makeDelivery(
                                    $transaction->id,
                                    $inputs['transaction']
                                );

                                $state = $prova->state;
                                $colony = $prova->colony;
                                $currier = 'Prova';

                                if ($resProva['success']) {
                                    $dataOrden['ordNbr'] = $resProva['data']->folio;
                                    $dataOrden['error_verify'] = 'OK';

                                    $referenceStatus = $resProva['data']->folio;
                                    $urlF = $resProva['data']->trakig_url;
                                } else {
                                    //Notificar a alguien porque no se creo el delivery en Prova y el pago se ejecuto
                                    $dataOrden['error_verify'] = 'ERROR';

                                    CustomLogs::addMessage(
                                        'Envío no procesado Prova (' . $transaction->id . '): ' . json_encode($resProva),
                                        $log
                                    );

                                    CustomLogs::sendErrorDelMail('Prova', $transaction->id);
                                }
                            }

                            if (!empty($voywey)) {
                                VoyweyDelivery::setTypePayment(
                                    $voywey->id,
                                    strtoupper($inputs['data_payment']['method']) == 'MP' ? 'MP' : 'D'
                                );

                                $resVoywey = voywey::makeDelivery(
                                    $transaction->id,
                                    $inputs['transaction'],
                                    strtoupper($inputs['data_payment']['method']) == 'MP' ? 'mp' : (!empty($paymenM) ? $paymenM : false),
                                    !empty($inputs['data_payment']['coupon']) ? strtolower($inputs['data_payment']['coupon']) : false,
                                    !empty($inputs['data_payment']['id']) ? $inputs['data_payment']['id'] : false
                                );

                                $state = $voywey->state;
                                $colony = $voywey->colony;
                                $currier = $voywey->courier_g;

                                if ($resVoywey['success']) {
                                    $dataOrden['ordNbr'] = $resVoywey['data']->folio;
                                    $dataOrden['error_verify'] = 'OK';

                                    $referenceStatus = $resVoywey['data']->folio;
                                    $urlF = $resVoywey['data']->trakig_url;
                                } else {
                                    //Notificar a alguien porque no se creo el delivery en 99min y el pago se ejecuto
                                    $dataOrden['error_verify'] = 'ERROR';

                                    CustomLogs::addMessage(
                                        'Envío no procesado Voywey (' . $transaction->id . '): ' . json_encode($resVoywey),
                                        $log
                                    );

                                    CustomLogs::sendErrorDelMail('Voywey', $transaction->id);
                                }
                            }

                            //NOTA: Si se implementa otro metodo de envio colocarlo aqui

                            //Creando orden
                            $dataOrden['totalAmount'] = $total;
                            $dataOrden['dni'] = $transaction->client_dni;
                            $dataOrden['amount_delivery'] = $transaction->price_sending;
                            $dataOrden['pricedetail'] = $transactionD->sum('price_pack');

                            if (
                                $infToken->accept_coupon == 'Y' &&
                                !empty($inputs['data_payment']['coupon'])
                            ) {

                                $objCodeR = Client::getClientByCodeR(trim(
                                    $inputs['data_payment']['coupon']
                                ));
                                if (!empty($objCodeR)) {
                                    $dataOrden['code_ref_status'] = 'A';
                                }

                                $cupon = Client::verifyCodeCupon($inputs['data_payment']['coupon']);
                                if (!empty($objCodeR) || $cupon) {
                                    //Es un cupon o un codigo de referido
                                    $dataOrden['discount'] = $discount;

                                    $codr = ($cupon) ? strtolower($inputs['data_payment']['coupon']) : strtoupper($inputs['data_payment']['coupon']);
                                    $dataOrden['cod_prom'] = $codr;
                                }
                            }

                            //Buscando el email del vendedor relacionado con el concentrador
                            if (empty($inputs['data_payment']['seller'])) {
                                $seller = User::getEmailByConc($infToken->concentrator_id);
                                $dataOrden['seller_email'] = !empty($seller) ? $seller->email : 'buscar-correo';
                            } else {
                                $dataOrden['seller_email'] = $inputs['data_payment']['seller'];
                            }

                            $orden = Ordens::createOrden($dataOrden);

                            if (!empty($orden)) {
                                if ($orden->code_ref_status = 'A' && !empty($objCodeR)) {

                                    $client_order = Client::getClientByDni($orden->client_id);

                                    $dataMail = array(
                                        'name' => $client_order->name,
                                        'last_name' => $client_order->last_name,
                                        'email' => $client_order->email
                                    );

                                    try {
                                        Mail::to($objCodeR->email)
                                            ->send(new Referred_congratulations($dataMail));
                                    } catch (\Exception $e) {
                                        Log::error('No se envio correo de compra referido. para la orden: ' . $orden->id . ', Error: ' . $e->getMessage());
                                        // Log::error((String) json_encode($dataMail));
                                        // Log::error((String) json_encode($objCodeR));

                                    }
                                }


                                //agregando id de orden a merado pago
                                if (strtoupper($inputs['data_payment']['method']) == 'MP') {
                                    $mp->order_id = $orden->id;
                                    $mp->save();
                                }

                                if (strtoupper($inputs['data_payment']['method']) == 'DEFERRED') {
                                    $payment->order_id = $orden->id;
                                    $payment->save();
                                }

                                //Creando detalle de orden
                                foreach ($transactionD as $detail) {
                                    $serv = ServiciabilityBuy::getServiciability($detail->serviciability_id);

                                    $namesArt = '';
                                    $sku = Articles::select('sku', 'title')
                                        ->where('id', $detail->id_artic)
                                        ->first();

                                    $namesArt .= $sku->title . ' ';
                                    $dataOD['artic'] = $detail->id_artic;
                                    $dataOD['serviceId'] = $detail->id_service;
                                    $dataOD['packPriceId'] = $detail->id_pack_price;
                                    $dataOD['dni'] = $transaction->client_dni;
                                    $dataOD['sku'] = $sku->sku;
                                    $dataOD['pricedetail'] = $detail->price_pack;
                                    $dataOD['id_detail'] = $detail->id;

                                    if (!empty($serv->lat)) {
                                        $dataOD['lat'] = $serv->lat;
                                    }

                                    if (!empty($serv->lng)) {
                                        $dataOD['lng'] = $serv->lng;
                                    }

                                    if (!empty($serv->serviciability)) {
                                        $dataOD['serviciability'] = $serv->serviciability;
                                    }

                                    if (!empty($serv->address)) {
                                        $dataOD['address'] = $serv->address;
                                    }

                                    $ordenDetail = OrdensDetail::createDetail($dataOD, $orden);
                                }

                                //Insertando primer estatus
                                OrdensStatus::insert([
                                    'id_ordens' => $orden->id,
                                    'description' => $descStatus,
                                    'status' => $ordenStatus,
                                    'date' => date('Y-m-d H:i:s'),
                                    'reference' => $referenceStatus,
                                    'send' => 'N',
                                ]);

                                //Cerrando transaccion
                                $transaction->status = 'P';
                                $transaction->save();

                                //Obteniendo datos del cliente
                                $clientD = Client::getClientByDni($transaction->client_dni);

                                if (!empty($clientD)) {

                                    //Se evalua la peticion para conocer al cliente
                                    //para extraer el codigo de referido o crearlo si es un hbb y no tenga aun code_ref
                                    //
                                    //Se obtiene el cliente en temp_Car
                                    $infoCodeR = null;
                                    if (!empty($clientD)) {
                                        //Se obtiene el articulo en temp_car_detail
                                        //
                                        $infoCodeR = !empty($clientD->code_ref) ? $clientD->code_ref : null;

                                        $detailEquip = TempCarDetail::getProductsDetail(
                                            $inputs['transaction'],
                                            $request->bearerToken()
                                        );

                                        if (count($detailEquip)) {
                                            if (is_null($infoCodeR) && $detailEquip[0]->artic_type == 'H') {
                                                //Se compro hbb y no tiene code_ref se crea uno

                                                $code_prefix = strtoupper(str_pad(substr($clientD->name, 0, 2), 2, Common::getRandText(2), STR_PAD_RIGHT) . str_pad(substr($clientD->last_name, 0, 2), 2, Common::getRandText(2), STR_PAD_RIGHT));

                                                $lastCodeClient = Client::getClientByCodeR(trim($code_prefix), 'like');

                                                $code = '001';

                                                if ($lastCodeClient) {
                                                    $code = str_pad(substr($lastCodeClient->code_ref, 4) + 1, 3, "0", STR_PAD_LEFT);
                                                }

                                                $infoCodeR = $code_prefix . $code;

                                                $lastCodeClient = Client::setCodeRef($transaction->client_dni, $infoCodeR);

                                                //Se envia un correo informando sobre el codigo de referido recien creado
                                                if (!empty($clientD->email)) {

                                                    $response = array(
                                                        'status' => 'success',
                                                        'code_ref' => $infoCodeR,
                                                    );

                                                    try {
                                                        Mail::to([$clientD->email])->send(new Referred_email_confirm($response));
                                                    } catch (\Exception $e) {

                                                        $textE = "Correo de notificacion de creacion de codigo de referido no enviado a " . $clientD->email;
                                                        CustomLogs::addMessage(
                                                            $textE,
                                                            $log
                                                        );

                                                        CustomLogs::registerLog(
                                                            'error',
                                                            $textE . ' Error: ' . $e->getMessage(),
                                                            'F',
                                                            $request,
                                                            $response
                                                        );
                                                    }
                                                }
                                            }
                                        }
                                    }
                                    //End de obtencion o creacion de codigo de referido

                                    if (!empty($clientD->email)) {

                                        //Enviando email de compra exitosa al cliente

                                        $data = [
                                            'amount' => $total,
                                            'concept' => $namesArt,
                                            'urlFolow' => !empty($urlF) ? str_replace('\\', '', $urlF) : '',
                                            'urlDetail' => env('URL_DETAIL') . $orden->id,
                                            'folio' => !empty($referenceStatus) ? $referenceStatus : '',
                                            'urlBuyStatus' => env('URL_SITE') . 'mi-netwey/estado-de-compra',
                                            'date' => date('Y-m-d H:i:s'),
                                        ];

                                        $textE = "Correo de compra exitosa no enviado a " . $clientD->email;

                                        if (strtoupper($inputs['data_payment']['method']) == 'DEFERRED') {
                                            try {
                                                Mail::to([$clientD->email])
                                                    ->send(new BuyOKSend($data));
                                            } catch (\Exception $e) {

                                                CustomLogs::addMessage(
                                                    $textE,
                                                    $log
                                                );

                                                CustomLogs::registerLog(
                                                    'error',
                                                    $textE . ' Error: ' . $e->getMessage(),
                                                    'F',
                                                    $request,
                                                    $response
                                                );
                                            }
                                        } else {
                                            try {
                                                Mail::to([$clientD->email])
                                                    ->send(new BuyOKV2($data));
                                            } catch (\Exception $e) {
                                                CustomLogs::addMessage(
                                                    $textE,
                                                    $log
                                                );

                                                CustomLogs::registerLog(
                                                    'error',
                                                    $textE . ' Error: ' . $e->getMessage(),
                                                    'F',
                                                    $request,
                                                    $response
                                                );
                                            }
                                        }
                                    }
                                }

                                //Enviando email de venta
                                if (strtoupper($inputs['data_payment']['method']) != 'DEFERRED') {
                                    CustomLogs::sendEmailSale(
                                        $infToken->name,
                                        $clientD->name . ' ' . $clientD->last_name,
                                        $clientD->phone_home,
                                        !empty($clientD->email) ? $clientD->email : 'S/I',
                                        $namesArt,
                                        $orden->id,
                                        $colony,
                                        $state,
                                        $paymenM,
                                        $currier,
                                        !empty($referenceStatus) ? $referenceStatus : false
                                    );
                                }

                                $response = [
                                    'success' => true,
                                    'folio' => !empty($dataOrden['ordNbr']) ? $dataOrden['ordNbr'] : false,
                                    'client' => [
                                        'code_ref' => $infoCodeR,
                                        'name' => $clientD->name . ' ' . $clientD->last_name,
                                    ],
                                    'data' => 'Transaccion procesada exitosamente.',
                                ];
                            } else {
                                $response['data']['cod_err'] = 'ERR_ORDER';
                                $response['data']['msg'] = 'No se pudo crear la orden';
                            }
                        }
                    } else {
                        $response['data']['cod_err'] = 'WT_INVENTARY';
                        $response['data']['msg'] = 'Artículo(s) sin inventario.';
                    }
                } else {
                    $response['data']['cod_err'] = 'TR_NOTVALID';
                    $response['data']['msg'] = 'Transacción no válida.';
                }
            } else {
                $response['data']['cod_err'] = 'TR_NOTVALID';
                $response['data']['msg'] = 'Transacción no válida..';
            }
        }

        //Finalizando log
        LogApiV2::finishLog(
            $log,
            $response,
            0,
            $response['success'] ? 'D' : 'E',
            !$response['success'] ? $response['data']['msg'] : ''
        );

        return response()->json($response);
    }

    /**
     * Actualiza el estatus de un pago a "dinero depositado a netwey".
     *
     * @param Illuminate\Http\Request $request
     * @return Object
     */
    public function markPayment(Request $request)
    {
        //Iniciando log
        $log = LogApiV2::initLog($request);

        $response = [
            'success' => false,
            'data' => ['cod_err' => 'ERR_PARAM', 'msg' => 'Faltan parámetros.'],
        ];

        $inputs = $request->input();

        $infToken = TokenApiSeller::getInfToken($request->bearerToken());

        if (!empty($inputs['payment_folio']) && !empty($inputs['payment_type']) && !empty($inputs['payment_status']) && ($inputs['payment_status'] == 'C' || $inputs['payment_status'] == 'A')) {
            $payment = DeferredPayment::getPayment($inputs['payment_folio']);

            if (!empty($payment)) {
                $doAct = false;

                $response['data']['cod_err'] = 'PAY_STATUSERR';
                $response['data']['msg'] = 'No se le puede asignar el estatus enviado al pago.';

                if ($inputs['payment_type'] == 'CASH') {
                    if ($payment->status == 'P') {
                        if ($inputs['payment_status'] == 'A') {
                            $doAct = true;
                        }
                    } elseif ($payment->status == 'A') {
                        if ($inputs['payment_status'] == 'C') {
                            $doAct = true;
                        }
                    }
                }

                if ($inputs['payment_type'] == 'CARD') {
                    if ($payment->status == 'P') {
                        if ($inputs['payment_status'] == 'C') {
                            $doAct = true;
                        }
                    }
                }

                if ($doAct) {
                    $payment->status = $inputs['payment_status'];
                    $payment->type_payment = $inputs['payment_type'];
                    $payment->date_update = date('Y-m-d H:i:s');
                    $payment->save();

                    if (($inputs['payment_type'] == 'CASH' && $inputs['payment_status'] == 'A') || ($inputs['payment_type'] == 'CARD' && $inputs['payment_status'] == 'C')) {
                        Jelou::reportPayment($inputs['payment_folio']);

                        $transaction = TempCar::getTransactionAP(
                            $payment->transaction,
                            $request->bearerToken()
                        );

                        if (!empty($transaction)) {
                            $transactionD = TempCarDetail::getTransactionDetailAP(
                                $payment->transaction,
                                $request->bearerToken()
                            );

                            //Consultando data de voywey
                            $voywey = VoyweyDelivery::getSendDelivery($transaction->id);

                            if (!empty($voywey)) {
                                foreach ($transactionD as $detail) {
                                    $namesArt = '';
                                    $sku = Articles::select('sku', 'title')
                                        ->where('id', $detail->id_artic)
                                        ->first();

                                    $namesArt .= $sku->title . ' ';
                                }

                                //Obteniendo datos del cliente
                                $clientD = Client::getClientByDni($transaction->client_dni);

                                //Enviando correo de venta exitosa
                                CustomLogs::sendEmailSale(
                                    $infToken->name,
                                    $clientD->name . ' ' . $clientD->last_name,
                                    $clientD->phone_home,
                                    !empty($clientD->email) ? $clientD->email : 'S/I',
                                    $namesArt,
                                    $payment->order_id,
                                    $voywey->colony,
                                    $voywey->state,
                                    ($inputs['payment_type'] == 'CASH' ? 'Efectivo' : 'Tarjeta'),
                                    'Voywey',
                                    $voywey->folio
                                );
                            }
                        }
                    }

                    $response = [
                        'success' => true,
                        'data' => 'Estatus actualizado exitosamente.',
                    ];
                }
            } else {
                $response['data']['cod_err'] = 'FOL_NOTVALID';
                $response['data']['msg'] = 'No se encontro el Folio.';
            }
        }

        //Finalizando log
        LogApiV2::finishLog(
            $log,
            $response,
            0,
            $response['success'] ? 'D' : 'E',
            !$response['success'] ? $response['data']['msg'] : ''
        );

        return response()->json($response);
    }
}
