<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\UserRole;
use App\Models\Organization;
use App\Models\SellerWare;
use App\Models\Profile;
use App\Utilities\Common;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use Symfony\Component\HttpFoundation\Response;

class SessionMiddleware
{
    /**
     * Handle an incoming request.
     *
     * @param  \Closure(\Illuminate\Http\Request): (\Symfony\Component\HttpFoundation\Response)  $next
     */
    public function handle(Request $request, Closure $next): Response
    {
        $start = microtime(true);

        $bearer_token = $request->bearerToken();

        if (empty($bearer_token)) {
            return response()->json(['error' => 'Unauthorized'], 401);
        }


        $user = User::getUserToFiber($bearer_token, 'R', ['A', 'D']);
        if (!empty($user)) {
            $routes = UserRole::getRolPolicies($user->email, ($user->status == 'D'));

            $mapRoutes = Common::getMapRoute();

            $routes = $routes->pluck('code');
            $permits = [];
            $permitsCode = [];
            foreach ($routes as $route) {
                if (!empty($mapRoutes[$route])) {
                    $permits = array_merge($mapRoutes[$route], $permits);
                }
                $permitsCode[] = $route;
            }

            #session(['permits_route' => $permits]);
            session(['permits_code' => $permitsCode]);

            $org = false;
            $wh = false;
            if (!empty($user->id_org)) {
                $userOrg = Organization::getOrg($user->id_org);

                if (!empty($userOrg)) {
                    $org = $userOrg->type;
                    $wh = SellerWare::getIdWare($user->email)
                        ->pluck('id_ware');
                }
            }

            //Apagando bandera de reinicio de sesión
            /* if ($user->reset_session == 'Y') {
                User::setResetSession($user->email, 'N');
            } */

            $lowH = Profile::getLowHer('commercial');

            session([
                'user' => $user->email,
                'name' => $user->name,
                'user_dni' => $user->dni,
                'user_type' => $user->platform,
                'last_name' => $user->last_name,
                'hierarchy' => $user->hierarchy,
                'low_hierarchy' => $lowH->hierarchy,
                'profile' => $user->name_profile,
                'profile_id' => $user->id_profile,
                'org' => !empty($user->id_org) ? $user->id_org : false,
                'org_type' => $org,
                'wh' => $wh,
                'last_login' => date('Y-m-d H:i:s')
            ]);
        }
        $end = microtime(true);
        $time = $end - $start;
        $response = $next($request);
        // Destruye la sesión al final de la solicitud
        Session::flush();

        return $response;

    }
}
