<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Models\Product;

class ArticlePack extends Model
{
    use HasFactory;

    protected $table = 'islim_arti_packs';

    protected $fillable = [
        'pack_id', 'inv_article_id', 'retail', 'status'
    ];

    protected $primaryKey = 'id';

    public $timestamps = false;

    /**
     * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
     * @param String $typeCon
     * 
     * @return App\models\ArticlePack
     */
    public static function getConnect($typeCon = false)
    {
        if ($typeCon) {
            $obj = new ArticlePack;
            $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

            return $obj;
        }
        return null;
    }

    /*
        Retorna el articulo asociado a un artic_pack dado el id pack y el id_artic, se consulta de esta forma para validar la existencia del pack y articulo.

        @param Integer $idPack
        @param Integer $idArtic
        @return Mix
    */
    public static function getDevice($idPack = false, $idArtic = false)
    {
        if ($idPack && $idArtic) {
            return self::getConnect('R')
                ->select(
                    'islim_packs.desc_web',
                    'islim_packs.pack_type',
                    'islim_inv_articles.description',
                    'islim_inv_articles.sku',
                    'islim_inv_articles.title'
                )
                ->join(
                    'islim_inv_articles',
                    'islim_inv_articles.id',
                    'islim_arti_packs.inv_article_id'
                )
                ->join(
                    'islim_packs',
                    'islim_packs.id',
                    'islim_arti_packs.pack_id'
                )
                ->where([
                    ['islim_arti_packs.status', 'A'],
                    ['islim_arti_packs.pack_id', $idPack],
                    ['islim_arti_packs.inv_article_id', $idArtic],
                    ['islim_packs.status', 'A'],
                    ['islim_inv_articles.status', 'A']
                ])
                ->first();
        }

        return null;
    }

    public static function getArticPackByPackId($id){
        return self::getConnect('R')
                    ->select(
                        'inv_article_id',
                        'retail'
                    )
                    ->where([
                        ['pack_id', $id],
                        ['status', 'A']
                    ])
                    ->first();
    }
}
