<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Exception;

class Client extends Model
{
    use HasFactory;

    protected $table = 'islim_clients';

    protected $fillable = [
        'dni',
        'user_mail',
        'reg_email',
        'name',
        'last_name',
        'address',
        'birthday',
        'email',
        'phone_home',
        'pwd_client',
        'date_ref',
        'phone',
        'date_reg',
        'note',
        'contact_date',
        'tokenPassword',
        'dateToken',
        'person_type',
        'require_invoice',
        'rfc',
        'postal_code',
        'municipe',
        'social',
        'campaign',
        'code_ref'
    ];

    protected $primaryKey = 'dni';

    public $incrementing = false;

    public $timestamps = false;

    /**
     * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
     * @param String $typeCon
     *
     * @return App\models\Client
     */
    public static function getConnect($typeCon = false)
    {
        if ($typeCon) {
            $obj = new Client;
            $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

            return $obj;
        }
        return null;
    }

    public static function getClient($email = false, $phone = false)
    {
        if ($email && $phone) {
            $data = self::getConnect('R')->where('email', $email)
                ->orWhere('phone_home', $phone);
        } elseif ($email) {
            $data = self::getConnect('R')->where('email', $email);
        } elseif ($phone) {
            $data = self::getConnect('R')->where('phone_home', $phone);
        }

        return $data->first();
    }

    public static function getClients($email = false, $phone = false)
    {
        if ($email && $phone) {
            $data = self::getConnect('R')->where('email', $email)
                ->orWhere('phone_home', $phone);
        } elseif ($email) {
            $data = self::getConnect('R')->where('email', $email);
        } elseif ($phone) {
            $data = self::getConnect('R')->where('phone_home', $phone);
        }

        return $data->get();
    }

    public static function getClientByDni($dni = false)
    {
        if ($dni) {
            return self::getConnect('R')->where('dni', $dni)->first();
        }

        return false;
    }

    public static function updateEmail($email, $dni)
    {
        return self::getConnect('W')
            ->where('dni', $dni)
            ->update(['email' => $email]);
    }

    public static function updateSecondPhone($phone, $dni)
    {
        return self::getConnect('W')
            ->where('dni', $dni)
            ->update(['phone' => $phone]);
    }

    public static function getClientByCodeR($codeR = false, $type = "full")
    {
        if ($codeR) {
            $codigo = self::getConnect('R');
            if ($type == "full") {
                $codigo = $codigo->where('code_ref', $codeR);
            } else {
                $codigo = $codigo->where('code_ref', 'like', $codeR . '%')
                    ->orderBy('code_ref', 'DESC');
            }
            return $codigo->first();
        }

        return false;
    }

    /**
     * [setCodeRef Establece el codigo de referido al cliente]
     * @param boolean $dni      [dni de la persona que se le asigna el codigo]
     * @param boolean $code_new [cadena del nuevo codigo]
     */
    public static function setCodeRef($dni = false, $code_new = false)
    {
        if ($dni && $code_new) {
            return self::getConnect('W')
                ->where('dni', $dni)
                ->update(
                    [
                        'email_confirm' => 'Y',
                        'code_ref' => $code_new
                    ]
                );
        }
        return false;
    }

    public static function verifyCodeCupon($code_ref = false)
    {
        //  $listCupones = array("ENVIOCERO", "DESPACHO0");
        if ($code_ref) {
            $listCupones = explode(',', env('CUPONES'));
            if (in_array(strtoupper($code_ref), $listCupones)) {
                return true;
            }
        }
        return false;
    }


    /**
	 * Metodo para consultar clientes o prospectos que coincidan con el valor de $search
	 *
	 * @param String $search
	 * @param Integer $limit
	 *
	 * @return App\Models\Client
	 */
	public static function searchClients($search = false, $limit = 20) {
		if ($search) {
			$nameClientAs = DB::raw('CONCAT(
        IFNULL(islim_clients.name,"")," ",
        IFNULL(islim_clients.last_name,"")," - Teléfono: ",
        IFNULL(islim_clients.phone_home,"S/N")) AS info');

			$infoClient = DB::raw('CONCAT(
        IFNULL(islim_clients.name,"")," ",
        IFNULL(islim_clients.last_name,"")," ",
        IFNULL(islim_clients.phone_home,""))');

			return self::getConnect('R')
				->select(
					$nameClientAs,
					'islim_clients.dni',
					'islim_clients.name',
					'islim_clients.last_name',
					'islim_clients.email',
					'islim_clients.address',
					'islim_clients.phone_home',
					'islim_clients.phone',
					'islim_client_netweys.msisdn'
				)
				->leftJoin(
					'islim_client_netweys',
					'islim_client_netweys.clients_dni',
					'islim_clients.dni'
				)
				->where(function ($query) use ($search, $infoClient) {
					$query->where('islim_clients.phone_home', $search)
						->orWhere('islim_clients.phone', $search)
						->orWhere('islim_client_netweys.msisdn', $search)
                        ->orWhere('islim_clients.dni', $search)
                        ->orWhere('islim_clients.email', 'like', '%' . $search . '%')
						->orWhere($infoClient, 'like', '%' . $search . '%');
				})
				->groupBy('islim_clients.dni')
				->limit($limit)
				->get();
		}
		return null;
	}

    /**
     * Metodo para consultar cliente o prospecto dado su dni
     *
     * @param String $dni
     *
     * @return App\Models\Client
     */
	public static function getFiberClientByDNI($dni = false) {
		if ($dni) {
			return self::getConnect('R')
				->select(
					'islim_clients.dni',
					'islim_clients.name',
					'islim_clients.last_name',
					'islim_clients.email',
					'islim_clients.address',
					'islim_clients.phone_home',
					'islim_clients.phone',
					'islim_client_netweys.msisdn',
					'islim_clients.code_curp',
					'islim_clients.verify_phone_id'
				)
				->leftJoin(
					'islim_client_netweys',
					'islim_client_netweys.clients_dni',
					'islim_clients.dni'
				)
				->where('islim_clients.dni', $dni)
				->first();
		}
		return null;
	}

    /**
     * [verifyPhones description]
     * @param  [type] $clientDni      [Dni del cliente que se esta revisando]
     * @param  [type] $phoneHome      [telefono principal del cliente]
     * @param  [type] $phoneSecondary [telefono sevundario del cliente]
     * @return [type]                 [description]
     */
	public static function verifyPhones($clientDni = false, $phoneHome, $phoneSecondary) {
		$existClientHome_1 = null;
		$existClientHome_2 = null;
		$existUserHome_1 = null;
		$existUserJob_1 = null;
		$exp_tlf = "/^[0-9]{10}$/";

		if (!empty($phoneHome)) {

			if (!preg_match($exp_tlf, $phoneHome)) {
				return ['success' => false, 'msg' => "El teléfono principal '" . $phoneHome . "' no es valido. Deben contener solo 10 digitos", 'code' => "INVALD_PHONE"];
			}
			//Telefono primario del cliente
			$existClientHome_1 = self::getConnect('R')
				->where('phone_home', $phoneHome);

			if ($clientDni) {
				$existClientHome_1 = $existClientHome_1->where('dni', '!=', $clientDni);
			}
			$existClientHome_1 = $existClientHome_1->first();

			//Telefono secundario cliente
			$existClientHome_2 = self::getConnect('R')
				->where('phone', $phoneHome);

			if ($clientDni) {
				$existClientHome_2 = $existClientHome_2->where('dni', '!=', $clientDni);
			}
			$existClientHome_2 = $existClientHome_2->first();

			//Telefono primario del usuarios de netwey
			$existUserHome_1 = User::getConnect('R')
				->where('phone', $phoneHome)
				->first();

			//Telefono secundario del usuarios de netwey
			$existUserJob_1 = User::getConnect('R')
				->where('phone_job', $phoneHome)
				->first();
		}

		$existClientSecondary_1 = null;
		$existClientSecondary_2 = null;
		$existUserHome_2 = null;
		$existUserJob_2 = null;

		if (!empty($phoneSecondary)) {
			if (!preg_match($exp_tlf, $phoneSecondary)) {
				return ['success' => false, 'msg' => "El teléfono secundario '" . $phoneSecondary . "' no es valido. Deben contener solo 10 digitos", 'code' => "INVALD_PHONE"];
			}

			if (!empty($phoneHome)) {
				if ($phoneHome == $phoneSecondary) {
					return ['success' => false, 'msg' => "El teléfono pricipal no puede ser el mismo teléfono secundario.", 'code' => "DUPLIC_PHONE"];
				}
			}

			//Telefono primario del cliente
			$existClientSecondary_1 = self::getConnect('R')
				->where('phone_home', $phoneSecondary);

			if ($clientDni) {
				$existClientSecondary_1 = $existClientSecondary_1->where('dni', '!=', $clientDni);
			}
			$existClientSecondary_1 = $existClientSecondary_1->first();

			//Telefono secundario cliente
			$existClientSecondary_2 = self::getConnect('R')
				->where('phone', $phoneSecondary);

			if ($clientDni) {
				$existClientSecondary_2 = $existClientSecondary_2->where('dni', '!=', $clientDni);
			}
			$existClientSecondary_2 = $existClientSecondary_2->first();

			//Telefono primario del usuarios de netwey
			$existUserHome_2 = User::getConnect('R')
				->where('phone', $phoneSecondary)
				->first();

			//Telefono secundario del usuarios de netwey
			$existUserJob_2 = User::getConnect('R')
				->where('phone_job', $phoneSecondary)
				->first();
		}

		if (empty($existClientHome_1) && empty($existClientHome_2) &&
			empty($existUserHome_1) && empty($existUserJob_1) && empty($existClientSecondary_1) && empty($existClientSecondary_2) && empty($existUserHome_2) && empty($existUserJob_2)) {
			return ['success' => true, 'msg' => "Telefono(s) libre de usarse", 'code' => "OK"];
		} else {
			if (!empty($existClientHome_1)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneHome . "' lo tiene registrado el cliente con identificador '#" . $existClientHome_1->dni . "' como teléfono principal. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_CLIENT"];
			} elseif (!empty($existClientHome_2)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneHome . "' lo tiene registrado el cliente con identificador '#" . $existClientHome_2->dni . "' como teléfono secundario. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_CLIENT"];
			} elseif (!empty($existUserHome_1)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneHome . "' lo tiene registrado el usuario '" . $existUserHome_1->email . "' como teléfono principal. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_USER"];
			} elseif (!empty($existUserJob_1)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneHome . "' lo tiene registrado el usuario '" . $existUserJob_1->email . "' como teléfono asignado. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_USER"];
			} elseif (!empty($existClientSecondary_1)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneSecondary . "' lo tiene registrado el cliente con identificador '#" . $existClientSecondary_1->dni . "' como teléfono principal. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_CLIENT"];
			} elseif (!empty($existClientSecondary_2)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneSecondary . "' lo tiene registrado el cliente con identificador '#" . $existClientSecondary_2->dni . "' como teléfono secundario. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_CLIENT"];
			} elseif (!empty($existUserHome_2)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneHome . "' lo tiene registrado el usuario '" . $existUserHome_2->email . "' como teléfono principal. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_USER"];
			} elseif (!empty($existUserJob_2)) {
				return ['success' => false, 'msg' => "El teléfono '" . $phoneHome . "' lo tiene registrado el usuario '" . $existUserJob_2->email . "' como teléfono asignado. Debes utilizar otro numero de teléfono", 'code' => "IS_PHONE_USER"];
			}
		}
		return ['success' => false, 'msg' => "Fallo la verificacion de teléfono", 'code' => "FAIL_VERIFIED"];
	}


    /**
     * [updateInfoContact Se registra los datos de contacto para el financimiento de telmovPay]
     * @param  boolean $ine   [description]
     * @param  boolean $curp  [description]
     * @param  boolean $phone [description]
     * @param  boolean $email [description]
     * @return [type]         [description]
     */
	public static function updateInfoContact($ine = false, $curp = false, $phone = false, $email = false) {
		if ($ine && $email) {

			//Verifico que el correo no lo tenga otro usuario
			$chekinMail = self::verifyMail($ine, $email);

			if ($chekinMail['success']) {

				try {
					$insr = self::getConnect('W')
						->where('dni', $ine)
						->first();

					$insr->email = strtolower(Common::normaliza($email));

					if ($curp) {
						$insr->code_curp = strtoupper((String) $curp);
					}
					if ($phone) {
						$insr->phone_home = $phone;
					}
					$insr->save();
					sleep(1);

				} catch (Exception $e) {
					$txmsg = 'Se presento un problema al actualizar los datos del cliente (MC578) ' . (String) json_encode($e->getMessage());
					Log::error($txmsg);
					return array('success' => false, 'error' => true, 'msg' => $txmsg);
				}

				if ($insr) {
					return array('success' => true, 'error' => false, 'msg' => 'Datos de contacto registrados correctamente');
				}
				return array('success' => true, 'error' => true, 'msg' => 'Datos de contacto no fue necesario actualizarlos');

			} else {
				return array('success' => false, 'error' => true, 'msg' => $chekinMail['msg']);
			}
		}
		return array('success' => false, 'error' => true, 'msg' => 'Faltan información para insertar los nuevos datos');
	}

    public static function verifyMail($dni = false, $email) {
		$exp_email = "/^[A-Za-z0-9][A-Za-z0-9._-]*[A-Za-z0-9]@[A-Za-z0-9]+(\.[A-Za-z0-9]+)*\.[a-zA-Z]{2,4}$/";
		if (preg_match($exp_email, $email)) {
			$data = self::getConnect('R')
				->select('dni')
				->whereRaw('LOWER(email) = "' . strtolower($email) . '"');

			if ($dni) {
				$data = $data->where('dni', '!=', $dni);
			}
			$data = $data->first();

			if (!empty($data)) {
				return ['success' => false, 'msg' => "El correo '" . $email . "' esta siendo usado por otro cliente '" . $data->dni . "'", 'code' => 'FAIL'];
			} else {
				return ['success' => true, 'msg' => "El correo '" . $email . "' esta libre de usarse", 'code' => 'OK'];
			}
		} else {
			return ['success' => false, 'msg' => "El correo '" . $email . "' tiene un formato no valido", 'code' => 'FAIL'];
		}
	}

    /**
	 * Metodo para consultar cliente dado su dni, telefono o email
	 *
	 * @param String $ine
	 * @param String $phone
	 * @param String $email
	 *
	 * @return App\Models\Client
	 */
	public static function getClientINEorDN($ine = false, $phone = false, $email = false) {
		if ($ine || $phone) {
			$data = self::getConnect('R')
				->select(
					'islim_clients.dni',
					'islim_clients.name',
					'islim_clients.last_name',
					'islim_clients.email',
					'islim_clients.phone_home',
					'islim_clients.phone',
					'islim_clients.address',
					'islim_clients.note',
					'islim_clients.birthday',
					'islim_clients.social',
					'islim_clients.contact_date',
					'islim_clients.verify_phone_id'
				);

			if ($phone && !$ine) {
				$data->where('islim_clients.phone_home', $phone);
			}

			if ($ine && !$phone) {
				$data->where('islim_clients.dni', $ine);
			}

			if ($ine && $phone && !$email) {
				$data->where(function ($q) use ($ine, $phone) {
					$q->where('islim_clients.dni', $ine)
						->orWhere('islim_clients.phone_home', $phone);
				});
			}

			if ($ine && !$phone && $email) {
				$data->where(function ($q) use ($ine, $email) {
					$q->where('islim_clients.dni', $ine)
						->orWhere('islim_clients.email', $email);
				});
			}

			if ($ine && $phone && $email) {
				$data->where(function ($q) use ($ine, $phone, $email) {
					$q->where('islim_clients.dni', $ine)
						->orWhere('islim_clients.phone_home', $phone)
						->orWhere('islim_clients.email', $email);
				});
			}

			return $data->first();
		}

		return null;
	}

	/**
	 * [isPermitUpdatePhone Revisa si se puede actualizar el telefono principal del prospecto]
	 * @param  [type]  $dni    [description]
	 * @param  [type]  $phone  [description]
	 * @param  [type]  $phone2 [description]
	 * @param  string  $origin [description]
	 * @return boolean         [description]
	 */
	public static function isPermitUpdatePhone($dni, $phone, $phone2, $origin = "Venta fibra") {
		$client = self::getClientINEorDN($dni);

		$errm = '';
		if (!empty($client)) {
			$phoneSecundary = $phone2;

			$chekingPhone = self::verifyPhones($dni, $phone, $phoneSecundary);

			if ($phone != $client->phone_home) {

				if (!$chekingPhone['success']) {
					$errm .= $chekingPhone['msg'];
				} else {
					//Si tengo la politica puedo editar celular, No se puede editar si fue verificado o si fue autorizado
					if (!empty($client->verify_phone_id) && !hasPermit('CLI-CNT')) {
						$errm .= "El teléfono principal del prospecto que esta actualmente registrado fue sometido a verificación, no estas autorizado para cambiarlo!";
						Log::alert("El vendedor '" . session('user') . "' intento actualizar el telefono principal del prospecto '" . $dni . "' el cual fue sometido a un proceso de verificación previamente. Es una acción atipica (" . $origin . ") " . date("Y-m-d H:i:s") . " --Telefono registrado: " . $client->phone_home . " Telefono que intento actualizar: " . $phone . " (CLI-CNT)");
					} else {
						if (!empty($client->verify_phone_id) && hasPermit('CLI-CNT')) {
							Log::alert("El vendedor '" . session('user') . "' tiene asignada la politica de actualizar el telefono principal del prospecto '" . $dni . "' el cual fue sometido a un proceso de verificación previamente. Es una acción que debio ser sometida a autorizacion previamente (" . $origin . ") " . date("Y-m-d H:i:s") . " --Telefono registrado: " . $client->phone_home . " Telefono que  actualizo: " . $phone . " (CLI-CNT)");
						}
					}
				}
			} elseif (!$chekingPhone['success']) {
				$errm .= $chekingPhone['msg'];
			}
		} else {
			$errm = "Prospecto con el dni " . $dni . " no existe en sistema";
		}

		if (empty($errm)) {
			$response = ['success' => true, 'msg' => "OK"];
		} else {
			$response = ['success' => false, 'msg' => $errm];
		}
		return $response;
	}


	/**
	 * [isPermitUpdateMail Revisa si se puede actualizar el correo de contacto del prospecto]
	 * @param  [type]  $dni    [description]
	 * @param  [type]  $email  [description]
	 * @param  string  $origin [description]
	 * @return boolean         [description]
	 */
	public static function isPermitUpdateMail($dni, $email, $origin = "Venta fibra") {
		$client = self::getClientINEorDN($dni);
		$errm = '';

		if (!empty($client)) {
			if (!empty($email)) {

				$chekinMail = self::verifyMail($dni, $email);

				if ($email != $client->email) {
					if (!$chekinMail['success']) {
						$errm .= !empty($errm) ? ', ' . $chekinMail['msg'] : $chekinMail['msg'];
					} else {
						//Si tengo la politica puedo editar celular
						if (!empty($client->verify_phone_id) && !hasPermit('CLI-CNT')) {
							//Se evalua si la verificacion del telefono primario uso el token que se envio por correo
							$typeVerify = Verify_contact_client::getRegisterVerify($client->verify_phone_id);

							if (!empty($typeVerify)) {
								if ($typeVerify->status == "VERIFIED" && $typeVerify->platform == "MAIL") {
									$errm .= "El correo del prospecto que esta actualmente registrado fue usado para un proceso de verificacion, no estas autorizado para cambiarlo!";
									Log::alert("El vendedor '" . session('user') . "' intento actualizar el correo del prospecto '" . $dni . "' el cual fue usado para verificar un celular previamente. Es una accion atipica (CLI-CNT)");
								}
							}
						} else {
							if (!empty($client->verify_phone_id) && hasPermit('CLI-CNT')) {
								Log::alert("El vendedor '" . session('user') . "' tiene asignada la politica de actualizar el correo del prospecto '" . $dni . "' el cual fue usado en un proceso de verificación previamente. Es una acción que debio ser sometida a autorizacion previamente (" . $origin . ") " . date("Y-m-d H:i:s") . " --Correo registrado: " . $client->email . " Correo que  actualizo: " . $email . " (CLI-CNT)");
							}
						}
					}
				} elseif (!$chekinMail['success']) {
					$errm .= !empty($errm) ? ', ' . $chekinMail['msg'] : $chekinMail['msg'];
				}
			}
		} else {
			$errm = "Prospecto con el dni " . $dni . " no existe en sistema";
		}

		if (empty($errm)) {
			$response = ['success' => true, 'msg' => "OK"];
		} else {
			$response = ['success' => false, 'msg' => $errm];
		}
		return $response;
	}


	public static function UpdateAddressClient($dni, $addressFormated) {
		try {
			$update_address = self::getConnect('W')
				->where('dni', $dni)
				->update([
					'address' => $addressFormated]);

			return ['success' => true, 'code' => 'OK', 'msg' => "Direccion actualizada del cliente"];
		} catch (Exception $e) {
			$Txmsg = "Error al actualizar la direccion del cliente " . $dni . " (MC940). " . (String) json_encode($e->getMessage());
			Log::error($Txmsg);
			return ['success' => false, 'code' => 'ERR_DB', 'msg' => $Txmsg];
		}
	}


	public static function updatePhoneSecondary($clientDni, $phone, $verify_phone = false) {
		try {
			$verify_phone = ($verify_phone) ? intval($verify_phone) : null;

			$updateSecondaryPhone = self::getConnect('W')
				->where('dni', $clientDni)
				->first();
			if (!empty($updateSecondaryPhone)) {
				$updateSecondaryPhone->phone = $phone;
				$updateSecondaryPhone->save();
				sleep(2);
				$updateSecondaryPhone->verify_phone_second_id = $verify_phone;
				$updateSecondaryPhone->save();

				return array('success' => true, 'title' => "Datos actualizados", 'msg' => "Registro de telefono secundario realizado exitosamente", 'icon' => "success", 'code' => "OK");
			}
			return array('success' => false, 'title' => "Datos no actualizados", 'msg' => "Registro del cliente no encontrado", 'icon' => "error", 'code' => "EMP_CLI");

		} catch (Exception $e) {
			$txmsg = 'Se presento un problema al actualizar los datos del cliente (MC666) ' . (String) json_encode($e->getMessage());
			Log::error($txmsg);
			return array('success' => false, 'title' => "Datos no actualizados", 'msg' => $txmsg, 'icon' => "error", 'code' => "FAIL_DB");
		}
	}


	/**
	 * [updatePhoneContact Registra el telefono verificado y el registro con el que se verifico dicho telefono]
	 * @param  [type]  $clientDni    [description]
	 * @param  [type]  $phone        [description]
	 * @param  boolean $verify_phone [description]
	 * @return [type]                [description]
	 */
	public static function updatePhoneContact($clientDni, $phone, $verify_phone = false) {
		$exist = self::getConnect('R')
			->where([
				['phone_home', $phone],
				['dni', '!=', $clientDni]])
			->first();

		if (empty($exist)) {
			//No hay otra persona con el telefono
			$verify_phone = ($verify_phone) ? intval($verify_phone) : null;

			try {
				$updateprimaryPhone = self::getConnect('W')
					->where('dni', $clientDni)
					->first();
				if (!empty($updateprimaryPhone)) {
					$updateprimaryPhone->phone_home = $phone;
					$updateprimaryPhone->save();
					sleep(2);
					$updateprimaryPhone->verify_phone_id = $verify_phone;
					$updateprimaryPhone->save();

					return array('success' => true, 'title' => "Datos actualizados", 'msg' => "Registro de telefono principal realizado exitosamente", 'icon' => "success", 'code' => "OK");
				}
				return array('success' => false, 'title' => "Datos no actualizados", 'msg' => "Registro del cliente no encontrado", 'icon' => "error", 'code' => "EMP_CLI");

			} catch (Exception $e) {
				$txmsg = 'Se presento un problema al actualizar los datos del cliente (MC619) ' . (String) json_encode($e->getMessage());
				Log::error($txmsg);
				return array('success' => false, 'title' => "Datos no actualizados", 'msg' => $txmsg, 'icon' => "error", 'code' => "FAIL_DB");
			}
		}
		return array('success' => false, 'title' => "Datos no actualizados", 'msg' => "El telefono " . $phone . " ya existe en sistema, verifique por favor el telefono suministrado", 'icon' => "error", 'code' => "PHONE_EXIST");
	}




}
