<?php

namespace App\Models;

use App\Models\FiberResponse;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class FiberQuestions extends Model
{
  use HasFactory;

  protected $table = 'islim_fiber_questions';

  protected $fillable = [
    'id',
    'description',
    'type',
    'status',
    'destiny',
    'order',
    'platform',
    'type_question'];

  public $timestamps = false;

  public static function getConnect($typeCon = false)
  {
    if ($typeCon) {
      $obj = new self;
      $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

      return $obj;
    }
    return null;
  }

  public static function getQuestionsByPlatform($dest = false, $typeQuestion)
  {
    $questions = self::getAllQuestion($dest, $typeQuestion);

    foreach ($questions as $value) {

      $value->options = FiberResponse::getOptionByQuestion($value->id);
    }

    return $questions;
  }

/**
 * [getAllQuestion Retorna las preguntas que se deben formular segun el tipo de pregunta y para que modulo se formula]
 * @param  boolean $dest         [Inicio o fin]
 * @param  [type]  $typeQuestion [instalacion, soporte o circulo]
 * @return [type]                [description]
 */
  public static function getAllQuestion($dest = false, $typeQuestion)
  {
    $pre = self::getConnect('R')
      ->where([
        ['status', 'A'],
        ['platform', 'SELLER']])
      ->wherein('type_question', ['ALL', $typeQuestion]);

    if ($dest) {
      $pre = $pre->where('destiny', $dest);
    }
    return $pre->get();
  }

  public static function getQuestionForInstall($idInstaller, $type)
  {
    $consulta = self::getConnect('R')
      ->select(
        'islim_fiber_questions.id',
        'islim_fiber_questions.description as q_description',
        'islim_fiber_questions.destiny',
        'islim_fiber_questions_result.question_result'
      )
      ->join('islim_fiber_question_response', 'islim_fiber_question_response.question_id', 'islim_fiber_questions.id')
      ->join('islim_fiber_questions_result', 'islim_fiber_questions_result.question_response_id', 'islim_fiber_question_response.id')
      ->where('islim_fiber_questions.platform', 'SELLER');

    if ($type == 'INSTALL') {
      $consulta->where('islim_fiber_questions_result.installation_id', $idInstaller);
    } elseif ($type == 'SUPPORT') {
      $consulta->where('islim_fiber_questions_result.support_id', $idInstaller);
    } else {
      $consulta->where('islim_fiber_questions_result.from_circle_credit_id', $idInstaller);
    }

    $resultado = $consulta->orderBy('islim_fiber_questions.order', 'ASC')
      ->distinct()
      ->get();

    return $resultado;
  }
}
