<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Log;

class HistorySmsFiber extends Model
{
  use HasFactory;

  protected $table = 'islim_history_sms_fiber';

  protected $fillable = [
    'id',
    'sms_nip_id',
    'installation_id',
    'dni_client',
    'process',
    'phone_sms',
    'email_netwey',
    'date_reg',
    'status'];

  public $timestamps = false;

  /**
   * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
   * @param String $typeCon
   *
   * @return App\HistorySmsFiber
   */
  public static function getConnect($typeCon = false)
  {
    if ($typeCon) {
      $obj = new self;
      $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

      return $obj;
    }
    return null;
  }

  public static function newHistorySMSFiber($data)
  {
    $response = ['success' => false, 'title' => "No se pudo registrar el historico", 'msg' => "Faltan datos", 'icon' => "error", 'code' => 'ERR_DAT'];

    if (!empty($data['sms_nip_id']) &&
      !empty($data['dni_client']) &&
      !empty($data['process']) &&
      !empty($data['phone_sms'])) {
      try {

        $data['email_netwey'] = session('user');
        $data['date_reg'] = date('Y-m-d H:i:s');

        $register = self::getConnect('W')
          ->insertGetId($data);

        $response['success'] = true;
        $response['title'] = "Registro insertado exitosamente";
        $response['msg'] = "Registrado nuevo historico de envio de sms al prospecto";
        $response['id'] = $register;
        $response['icon'] = "success";
        $response['code'] = "OK";
      } catch (Exception $e) {
        $txmsg = "No se pudo registrar nuevo historico de envio de sms al prospecto: " . $data['dni_client'] . " - (MHSF68) " . (String) json_encode($e->getMessage());
        Log::error($txmsg);
        $response = ['success' => false, 'title' => "No se pudo procesar la solicitud de registro", 'msg' => $txmsg, 'icon' => "error", 'code' => 'ERR_DAT'];
      }
    }
    return $response;
  }
}
