<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;

class LogApiV2 extends Model
{
    use HasFactory;

    protected $table = 'islim_log_api_seller_v2';

    public $initTime = 0;

    protected $fillable = [
        'ip',
        'user',
        'transaction',
        'headers',
        'url',
        'type',
        'data_in',
        'data_out',
        'message',
        'time',
        'date_reg'
    ];

    public $timestamps = false;

    /**
     * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
     * @param String $typeCon W para lectura-escritura, cualquier otro valor para solo lectura
     *
     * @return App\Models\LogApiV2
     */
    public static function getConnect($typeCon = false)
    {
        if ($typeCon) {
            $obj = new LogApiV2;
            $obj->initTime = microtime(true);
            $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

            return $obj;
        }

        return null;
    }

    /**
     * Metodo para inicializar un registro de log
     * @param Illuminate\Http\Request $request
     * @param String $message opcional, si se envía se agrega un mesanje al log
     * @param Char $type opcional, sirve para marcar si el log es un error(E) o solo debug(D)
     *
     * @return App\Models\LogApiV2
     */
    public static function initLog(Request $request, $message = false, $type = 'D')
    {
        $log = self::getConnect('W');

        $log->ip = $request->ip();
        $log->url = $request->fullUrl();
        $log->data_in = (string)json_encode($request->input());
        $log->headers = (string)json_encode($request->header());

        if (!empty($request->bearerToken())) {
            $log->user = $request->bearerToken();
        }

        if ($message) {
            $log->message = $message;
        }

        $inputs = $request->input();

        $transaction = $request->route('transaction') ?? false;

        if (!empty($inputs['transaction']) || $transaction) {
            $log->transaction = $transaction ? $transaction : $inputs['transaction'];
        }

        $log->type = $type;
        $log->date_reg = date('Y-m-d H:i:s');
        $log->save();

        return $log;
    }

    /**
     * Metodo para finalizar un registro de log
     * @param App\Models\LogApiV2 $log objeto devuelto por el metodo initLog
     * @param Array $response opcional, si se envía debe ser un array asociativo 
     * que se guardara como data enviada
     * @param Int $time opcional, si se envia se registra el tiempo que tardo el request 
     * en optener una respuesta, en caso de que no se envíe y si existe se tomara el tiempo
     * de la propiedad initTime de la clase LogApiV2 el cual es inicializado al momento de crear
     * el objeto con el metodo getConnect
     * @param Char $type opcional, sirve para marcar si el log es un error(E) o solo debug(D)
     * @param String $message opcional, si se envía se agrega un mesanje al log
     *
     * @return App\Models\LogApiV2
     */
    public static function finishLog(LogApiV2 $log, $response = [], int $time = 0, $type = 'D', $message = false)
    {
        if (!empty($log->initTime)) {
            $log->time = round((microtime(true) - $log->initTime), 2);
        } elseif ($time > 0) {
            $log->time = round((microtime(true) - $time), 2);
        }

        if ($message) {
            $log->message = !empty($log->message) ? ($log->message . ' ' . $message) : $message;
        }

        $log->type = $type;

        $log->data_out = (string)json_encode($response);
        $log->save();

        return $log;
    }

    public static function deleteLogs($date)
    {
        return self::getConnect('W')
            ->where('date_reg', '<=', $date)
            ->delete();
    }
}
