<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class NinetyNineMinutes extends Model
{
    use HasFactory;

    protected $table = 'islim_ninety_nine_minutes';

    protected $fillable = [
        'id_car',
        'id_temp_car',
        'postal_code',
        'route',
        'neighborhood',
        'municipality',
        'state',
        'street_number',
        'internal_number',
        'notes',
        'sub_locality',
        'locality',
        'delivery_type',
        'vehicle_type',
        'received_order',
        'order99',
        'url_pdf',
        'price',
        'status',
        'date_reg',
    ];

    public $timestamps = false;

    /**
     * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
     * @param String $typeCon
     *
     * @return App\models\NinetyNineMinutes
     */
    public static function getConnect($typeCon = false)
    {
        if ($typeCon) {
            $obj = new NinetyNineMinutes;
            $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

            return $obj;
        }
        return null;
    }

    public static function getActiveDelivery($idCar = false)
    {
        if ($idCar) {
            return self::getConnect('R')
                ->select(
                    'id',
                    'postal_code',
                    'route',
                    'neighborhood',
                    'sub_locality',
                    'municipality',
                    'state',
                    'notes',
                    'street_number',
                    'internal_number',
                    'price',
                    'delivery_type',
                    'vehicle_type',
                    'locality'
                )
                ->where([
                    ['id_temp_car', $idCar],
                    ['status', 'A'],
                ])
                ->first();
        }

        return null;
    }

    public static function getActOrSendDelivery($idCar = false)
    {
        if ($idCar) {
            return self::getConnect('R')
                ->select('id', 'order99')
                ->where('id_temp_car', $idCar)
                ->whereIn('status', ['A', 'S'])
                ->first();
        }

        return null;
    }

    public static function resetDelivery($transaction)
    {
        return self::getConnect('W')
            ->where('id_temp_car', $transaction)
            ->update(['status' => 'I']);
    }

    /*DEPRECATED*/
    public static function getAddressWh($cp = false)
    {
        if ($cp) {
            return DB::table('islim_pcs_99')
                ->select(
                    'islim_warehouses.route',
                    'islim_warehouses.street_number',
                    'islim_warehouses.neighborhood',
                    'islim_warehouses.locality',
                    'islim_warehouses.subLocality',
                    'islim_warehouses.state',
                    'islim_warehouses.cp'
                )
                ->join(
                    'islim_warehouses',
                    'islim_warehouses.id',
                    'islim_pcs_99.warehouse'
                )
                ->where([
                    ['islim_pcs_99.status', 'A'],
                    ['islim_pcs_99.postal_code', $cp],
                ])
                ->first();
        }
        return null;
    }
}
