<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class PackPrices extends Model
{
    use HasFactory;

    protected $table = 'islim_pack_prices';

    protected $fillable = [
        'id',
        'pack_id',
        'service_id',
        'type',
        'price_pack',
        'price_serv',
        'total_price',
        'status',
        'id_financing',
    ];

    public $timestamps = false;

    /**
     * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
     * @param String $typeCon
     *
     * @return App\models\PackPrices
     */
    public static function getConnect($typeCon = false)
    {
        if ($typeCon) {
            $obj = new PackPrices;
            $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

            return $obj;
        }
        return null;
    }

    /**
     * Retorna los serivicos asociados a un pack
     *
     * @param Array $packIds
     * @param Array $broadbands
     * @return Array
     **/
    public static function getServices($packIds = [], $broadbands = [])
    {
        $data = self::getConnect('R')
            ->select(
                'islim_pack_prices.id as packpriceId',
                'islim_pack_prices.total_price',
                'islim_services.id as serviceId',
                'islim_services.title',
                'islim_services.description'
            )
            ->join('islim_services', 'islim_services.id', 'islim_pack_prices.service_id')
            ->whereIn('islim_pack_prices.pack_id', $packIds)
            ->where([
                ['islim_pack_prices.status', 'A'],
                ['islim_services.status', 'A'],
                ['islim_services.type', 'A'],
            ]);

        if (count($broadbands)) {
            $data->whereIn('islim_services.broadband', $broadbands);
        }

        return $data->get();
    }

    /*
  Retorna los serivicos asociados a un pack

  @param Array $Ids
  @param Array $broadbands
  @return Array
   */
    public static function getServicesOffer($Ids = [], $broadbands = [])
    {
        if (is_array($Ids) && count($Ids) && is_array($broadbands) && count($broadbands)) {
            return self::getConnect('R')
                ->select(
                    'islim_pack_prices.id as packpriceId',
                    'islim_pack_prices.total_price',
                    'islim_services.id as serviceId',
                    'islim_services.title',
                    'islim_services.description'
                )
                ->join('islim_services', 'islim_services.id', 'islim_pack_prices.service_id')
                ->whereIn('islim_pack_prices.id', $Ids)
                ->whereIn('islim_services.broadband', $broadbands)
                ->where([
                    ['islim_pack_prices.status', 'A'],
                    ['islim_services.status', 'A'],
                    ['islim_services.type', 'A'],
                ])
                ->get();
        }

        return [];
    }

    /**
  Retorna el servicio asociado a un pack dado el id del pack_price y el servicio, se consulta de esta forma para validar la existencia del pack y servicio.

  @param Integer $pricePack
  @param Integer $service
  @return Mix
     */
    public static function getService($pricePack = false, $service = false)
    {
        if ($pricePack && $service) {
            return self::getConnect('R')
                ->select(
                    'islim_pack_prices.total_price',
                    'islim_services.title',
                    'islim_services.gb',
                    'islim_services.description'
                )
                ->join('islim_services', 'islim_services.id', 'islim_pack_prices.service_id')
                ->where([
                    ['islim_pack_prices.id', $pricePack],
                    ['islim_pack_prices.service_id', $service],
                    ['islim_pack_prices.status', 'A'],
                    ['islim_services.status', 'A'],
                    ['islim_services.type', 'A'],
                ])
                ->first();
        }

        return null;
    }

    public static function getPackPriceByPackId($id, $statusList = ['A'])
    {
        return self::getConnect('R')
        ->select(
            'service_id',
            'id_financing',
            'price_pack',
            'price_serv',
            'total_price'
        )
        ->where('pack_id', $id)
        ->whereIn('status', $statusList)
        ->first();
    }
}
