<?php

namespace App\Models;

use App\Models\TempCar;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class TempCarDetail extends Model
{
    use HasFactory;

    protected $table = 'islim_temp_car_detail';

    protected $fillable = [
        'service_address',
        'serviciability_id',
        'id_pack',
        'id_artic',
        'id_pack_price',
        'id_service',
        'transaction',
        'price_pack',
        'date_reg',
        'date_update',
        'status'
    ];

    const CREATED_AT = 'date_reg';
    const UPDATED_AT = 'date_update';

    /**
     * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
     * @param String $typeCon
     *
     * @return App\models\TempCarDetail
     */
    public static function getConnect($typeCon = false)
    {
        if ($typeCon) {
            $obj = new TempCarDetail;
            $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

            return $obj;
        }
        return null;
    }

    public static function deleteItemTransaction($transaction)
    {
        return self::getConnect('W')
            ->where(
                'transaction',
                $transaction
            )
            ->update(['status' => 'T']);
    }

    public static function getTransactionDetail($transaction = false, $token = false)
    {
        if ($transaction && $token) {
            return self::getConnect('R')
                ->select(
                    'islim_temp_car_detail.*',
                    'islim_inv_articles.sku'
                )
                ->join(
                    'islim_temp_car',
                    'islim_temp_car.transaction',
                    'islim_temp_car_detail.transaction'
                )
                ->join(
                    'islim_inv_articles',
                    'islim_inv_articles.id',
                    'islim_temp_car_detail.id_artic'
                )
                ->where([
                    ['islim_temp_car.transaction', $transaction],
                    ['islim_temp_car.key', $token],
                    ['islim_temp_car.status', 'A'],
                    ['islim_temp_car_detail.status', 'A']
                ])
                ->get();
        }

        return [];
    }

    public static function getTransactionDetailAP($transaction = false, $token = false)
    {
        if ($transaction && $token) {
            return self::getConnect('R')
                ->select('islim_temp_car_detail.*')
                ->join(
                    'islim_temp_car',
                    'islim_temp_car.transaction',
                    'islim_temp_car_detail.transaction'
                )
                ->where([
                    ['islim_temp_car.transaction', $transaction],
                    ['islim_temp_car.key', $token],
                    ['islim_temp_car_detail.status', 'A']
                ])
                ->whereIn('islim_temp_car.status', ['A', 'P'])
                ->get();
        }

        return [];
    }

    public static function getProductsDetail($transaction = false, $token = false)
    {
        if ($transaction && $token) {
            return self::getConnect('R')
                ->select(
                    'islim_inv_articles.id',
                    'islim_inv_articles.title',
                    'islim_inv_articles.artic_type',
                    'islim_temp_car_detail.price_pack',
                    'islim_services.title as service'
                )
                ->join(
                    'islim_temp_car',
                    'islim_temp_car.transaction',
                    'islim_temp_car_detail.transaction'
                )
                ->join(
                    'islim_services',
                    'islim_services.id',
                    'islim_temp_car_detail.id_service'
                )
                ->join(
                    'islim_inv_articles',
                    'islim_inv_articles.id',
                    'islim_temp_car_detail.id_artic'
                )
                ->where([
                    ['islim_temp_car.transaction', $transaction],
                    ['islim_temp_car.key', $token],
                    ['islim_temp_car.status', 'A'],
                    ['islim_temp_car_detail.status', 'A']
                ])
                ->orderBy('islim_temp_car_detail.date_reg', 'DESC')
                ->get();
        }

        return [];
    }
}
