<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class VoyweyDelivery extends Model
{
    use HasFactory;

    protected $table = 'islim_voywey_delivery';

    protected $fillable = [
        'id_car',
        'id_temp_car',
        'deposit',
        'postal_code',
        'state',
        'city',
        'colony',
        'municipality',
        'street',
        'street2',
        'ext_number',
        'int_number',
        'notes',
        'transaction',
        'folio',
        'traking_url',
        'courier_g',
        'shipment_id',
        'shipment_type_id',
        'price',
        'prices',
        'lat',
        'lng',
        'delivery_date',
        'status',
        'date_reg',
        'type_payment'
    ];

    public $timestamps = false;

    /**
     * Metodo para seleccionar conexion a la bd, escritura-lectura o solo escritura
     * @param String $typeCon
     *
     * @return App\models\VoyweyDelivery
     */
    public static function getConnect($typeCon = false)
    {
        if ($typeCon) {
            $obj = new VoyweyDelivery;
            $obj->setConnection($typeCon == 'W' ? 'mysql::write' : 'mysql::read');

            return $obj;
        }
        return null;
    }

    public static function getActOrSendDelivery($idCar = false)
    {
        if ($idCar) {
            return self::getConnect('R')
                ->select('id', 'courier_g', 'folio')
                ->where('id_temp_car', $idCar)
                ->whereIn('status', ['A', 'S'])
                ->first();
        }

        return null;
    }

    public static function getActiveDelivery($car_id = false)
    {
        if ($car_id) {
            return self::getConnect('R')
                ->select(
                    'id',
                    'postal_code',
                    'deposit',
                    'street',
                    'municipality',
                    'colony',
                    'state',
                    'notes',
                    'ext_number',
                    'price',
                    'transaction',
                    'courier_g'
                )
                ->where([
                    ['id_temp_car', $car_id],
                    ['status', 'A'],
                ])
                ->first();
        }

        return null;
    }

    public static function getSendDelivery($car_id = false)
    {
        if ($car_id) {
            return self::getConnect('R')
                ->select(
                    'id',
                    'postal_code',
                    'deposit',
                    'street',
                    'municipality',
                    'colony',
                    'state',
                    'folio',
                    'notes',
                    'ext_number',
                    'price',
                    'transaction'
                )
                ->where([
                    ['id_temp_car', $car_id],
                    ['status', 'S'],
                ])
                ->first();
        }

        return null;
    }

    public static function resetDelivery($transaction)
    {
        return self::getConnect('W')
            ->where('id_temp_car', $transaction)
            ->update(['status' => 'I']);
    }

    public static function setTypePayment($id, $type)
    {
        return self::getConnect('W')
            ->where('id', $id)
            ->update(['type_payment' => $type]);
    }
}
