<?php

namespace App\Utilities;

use App\Models\LogApiV2;

use App\Utilities\Common;
use App\Utilities\CustomLogs;
use Log;
/*
	Clase que contiene metodos para conectarse con la API altan-netwey, se pueden utilizar desde cualqueir controlador
*/

class Altan
{

	/*
   		Retorna la servicialidad de un DN
   		@param String $lat
   		@param String $lng
   		@param String $token Token para la api de netwey-altan
   		@param Illuminate\Http\Request $request
   		@return Object 
   	*/
	public static function getServiceability($lat = false, $lng = false, $token = false, $request = false, LogApiV2 $log = null, $typePack = 'H')
	{
		if ($lat && $lng && $token) {
			$data = [
				'lat' => $lat,
				'lng' => $lng,
				'apiKey' => $token
			];

			if ($typePack == 'MH') {
				$data['mobility'] = 'Y';
			}

			//Consultan servicialidad en altan
			$res = Common::executeCurl(env('URL_ALTAM') . 'serviceability/', 'POST', [], $data);

			/*$typePack == 'MH' && !empty($res['data']->service) && $res['data']->service == 'E-BLK'*/
			if ($res['success'] && strtolower($res['data']->status) == 'success') {
				return $res['data']->service;
			}

			if ($request) {
				CustomLogs::registerLog(
					'notice',
					'Sin servicialidad en lat: ' . $lat . ' lng: ' . $lng . ' (getServiceability)',
					'F',
					$request,
					$res
				);
			}
		}

		if (!empty($log)) {
			CustomLogs::addMessage(
				'Sin servicialidad en lat: ' . $lat . ' lng: ' . $lng . ' (getServiceability) ' . (!empty($res) ? json_encode($res) : ''),
				$log
			);
		}

		return false;
	}

	/*
   		Retorna latitud y longitud de una direccion en caso de poderse extraer
   		@param App\Utilities\Common::getAddressInfo $address
   		@return Mix 
   	*/
	public static function getLatLngFromAddress($address = false, LogApiV2 $log = null)
	{
		if ($address) {
			if (
				$address['success'] &&
				!empty($address['data'][0]) &&
				!empty($address['data'][0]->geometry) &&
				!empty($address['data'][0]->geometry->location) &&
				!empty($address['data'][0]->geometry->location->lat) &&
				!empty($address['data'][0]->geometry->location->lng)
			)
				return [
					'success' => true,
					'lat' => $address['data'][0]->geometry->location->lat,
					'lng' => $address['data'][0]->geometry->location->lng
				];
		}

		if (!empty($log)) {
			CustomLogs::addMessage(
				'No se encontro la lat y la lng de la dirección enviada.',
				$log
			);
		}

		return ['success' => false];
	}

	public static function validIMEI($imei = false){
		if($imei){

			$data['apiKey'] = env('API_KEY_ALTAM');

			$response = Common::executeCurl(
							env('URL_API_ALTAM').'/imei-status/'.$imei,
							'POST',
							[
								'Content-Type: application/json',
								'cache-control: no-cache'
							],
							$data
						);

			//todo:Simulacion de respuesta, quitar cuando se envie a prod
			if($imei == "354301560246153"){
				$response = [
					"success" => true,
					"data" => (object) [
						"status" => "success",
						"imei" => (object) [
							"imei" => "35430156024615",
							"homologated" => "COMPATIBLE HOMOLOGADO",
							"blocked" => "NO",
							"sub_category" => "Voz y Datos",
							"soportaESIM" => "NO"
						],
						"deviceFeatures" => (object) [
							"volteCapable" => "SI",
							"band28" => "SI",
							"model" => "SM-A107M",
							"brand" => "Samsung"
						]
					],
					"original" => '{"status":"success","imei":{"imei":"35430156024615","homologated":"COMPATIBLE HOMOLOGADO","blocked":"NO","sub_category":"Voz y Datos","soportaESIM":"NO"},"deviceFeatures":{"volteCapable":"SI","band28":"SI","model":"SM-A107M","brand":"Samsung"}}',
					"code" => 200
				];
			}

			if($response['success'] && $response['data']->status == 'success'){
				if(strtoupper($response['data']->deviceFeatures->band28) == 'SI' || strtoupper($response['data']->deviceFeatures->band28) == 'NO'){
					return [
						'success' => true,
						'data' => [
							'homologated' => !empty($response['data']->imei->homologated)?$response['data']->imei->homologated:'S/I',
							'blocked' => !empty($response['data']->imei->blocked)?$response['data']->imei->blocked:'S/I',
							'volteCapable' => !empty($response['data']->deviceFeatures->volteCapable)? strtolower($response['data']->deviceFeatures->volteCapable):'S/I',
							'model' => !empty($response['data']->deviceFeatures->model)?$response['data']->deviceFeatures->model:'S/I',
							'brand' => !empty($response['data']->deviceFeatures->brand)?$response['data']->deviceFeatures->brand:'S/I',
							'band28' => strtoupper($response['data']->deviceFeatures->band28)
						]
					];
				}
			}else{
				Log::error('Ocurrio un error al intentar Validar IMEI: '.$imei, $response);
			}
		}

		return ['success' => false];
	}
}
