<?php

namespace App\Utilities;

use Illuminate\Support\Arr;
use Illuminate\Support\Facades\DB;

/*Clase que contiene metodos "varios" que se pueden utilizar desde cualqueir controlador*/

class Common
{

    /*
  Ejecuta un curl

  @url string endpoint
  @type string tipo de ejecucion [GET, POST, DELETE, ..]
  @header array campo opcional, de ser enviado reemplaza la cabecera que se envia en el curl
  @data array data que sera enviada en el curl
   */
    public static function executeCurl($url = false, $type = false, $header = [], $data = [])
    {
        if ($url && $type) {
            $curl = curl_init();

            if (!count($header)) {
                $header = [
                    "accept: */*",
                    "Content-Type: application/json",
                    "cache-control: no-cache",
                    "accept-language: en-US,en;q=0.8",
                ];
            }

            $options = [
                CURLOPT_URL => $url,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => "",
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 180,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => $type,
                CURLOPT_HTTPHEADER => $header,
            ];

            if (count($data)) {
                $options[CURLOPT_POSTFIELDS] = json_encode($data);
            }

            curl_setopt_array($curl, $options);

            $response = curl_exec($curl);
            $httpcode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
            $err = curl_error($curl);

            curl_close($curl);

            if ($err) {
                return ['success' => false, 'data' => $err];
            } else {
                $dataJson = json_decode($response);

                if (!empty($dataJson)) {
                    return [
                        'success' => true,
                        'data' => $dataJson,
                        'original' => $response,
                        'code' => !empty($httpcode) ? $httpcode : 0,
                    ];
                } else {
                    return [
                        'success' => false,
                        'data' => 'No se pudo obtener json.',
                        'original' => $response,
                        'code' => !empty($httpcode) ? $httpcode : 0,
                    ];
                }
            }
        }

        return ['success' => false, 'data' => 'Faltan datos.'];
    }

    /*
  Retorna n digitos aleatorios
  @param Integer $n número de digitos a generar
  @param Integer $b rango inferior para la generacion de números aleatorios
  @param Integer $e rango superior para la generacion de números aleatorios
  @return Integer
   */
    public static function getRandDig($n = 0, $b = 1, $e = 9)
    {
        if ($n > 0) {
            mt_srand(time());
            $digits = '';
            for ($i = 0; $i < $n; $i++) {
                $digits .= mt_rand($b, $e);
            }
            return $digits;
        }
        return 0;
    }

    /**
     * [getRandText Genera una cadena de texto aleatoria]
     * @param  integer $limit [tamano de la cadena a generar]
     * @param  string  $type  [tipo de letras a usar]
     * @return [type]         [description]
     */
    public static function getRandText($limit = 1, $type = "upper")
    {
        if ($type == "upper") {
            $caracteres_permitidos = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
        } elseif ($type == "lower") {
            $caracteres_permitidos = "abcdefghijklmnopqrstuvwxyz";
        } else {
            //mixto
            $caracteres_permitidos = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
        }
        $longitud = $limit;
        $prefix = substr(str_shuffle($caracteres_permitidos), 0, $longitud);

        return $prefix;
    }

    /*
  Retornar un entero verificando los ultimos tres o dos caracteres de una cadena
  @param String $str cadena a la que se le quiere extraer el número
  @return Integer
   */
    public static function getLastNumber($str = 0)
    {
        $str = substr($str, strlen($str) - 3, strlen($str));

        if (is_numeric($str)) {
            return (int) $str;
        } else {
            $str = substr($str, strlen($str) - 2, strlen($str));

            if (is_numeric($str)) {
                return (int) $str;
            } else {
                $str = substr($str, strlen($str) - 1, strlen($str));
                if (is_numeric($str)) {
                    return (int) $str;
                }
            }
        }

        return 0;
    }

    /*
  Retorna true si el ancho de banda que se quiere activar es permitido para el usuario
  @param String $newWide
  @param String $serviceWide
  @param Boolean $equal
  @return Boolean
   */
    public static function compareWide($newWide = false, $serviceWide = false, $equal = false)
    {
        if ($newWide && $serviceWide) {
            $newWide = SELF::getLastNumber($newWide);
            $serviceWide = SELF::getLastNumber($serviceWide);
            if ($equal) {
                return ($newWide != 0 && $serviceWide != 0 && $newWide == $serviceWide);
            }

            return ($newWide != 0 && $serviceWide != 0 && $newWide > $serviceWide);
        }
        return false;
    }

    /*
  Retorna el base64 de un string dado sin los "=="
  @param String $str
  @return String
   */
    public static function getCleanBase64($str = false)
    {
        if ($str) {
            return str_replace('=', '', base64_encode($str));
        }

        return '';
    }

    /*
  Retorna un array de estafetas con sus datos

  @param App\Estafeta $estafetas
  @return array
   */
    public static function getEstafetasArray($estafetas = false)
    {
        if ($estafetas && $estafetas->count()) {
            foreach ($estafetas as $estafeta) {
                $response[] = [
                    'cod_estafeta' => !empty($estafeta->code) ? $estafeta->code : '',
                    'number' => !empty($estafeta->number) ? $estafeta->number : '',
                    'street' => !empty($estafeta->street) ? $estafeta->street : '',
                    'street_1' => !empty($estafeta->street_1) ? $estafeta->street_1 : '',
                    'street_2' => !empty($estafeta->street_2) ? $estafeta->street_2 : '',
                    'postal_code' => !empty($estafeta->cp) ? $estafeta->cp : '',
                    'municipe' => !empty($estafeta->municipe) ? $estafeta->municipe : '',
                    'colony' => !empty($estafeta->colony) ? $estafeta->colony : '',
                    'state' => !empty($estafeta->state) ? $estafeta->state : '',
                ];
            }

            return $response;
        }

        return [];
    }

    public static function validateInventoryEstafeta($artics = [], $Articles = false)
    {
        if (!empty($artics) && count($artics) && !empty($Articles)) {
            foreach ($artics as $artic) {
                $sku = $Articles::select('sku')
                    ->where([
                        ['status', 'A'],
                        ['id', $artic],
                    ])
                    ->first();

                if (!empty($sku)) {
                    if (empty($countArt[$sku->sku])) {
                        $skus[] = ['sku' => $sku->sku];
                    }

                    $countArt[$sku->sku] = empty($countArt[$sku->sku]) ? 0 : ($countArt[$sku->sku] + 1);
                }
            }

            if (count($skus)) {
                $dataBri = ['data' => $skus];
                $resB = self::executeCurl(env('API_BRI') . 'get-inventary-brightstar', 'POST', [], $dataBri);

                if ($resB['success'] && !empty($resB['data']->data) && count($resB['data']->data)) {
                    $obj = Arr::where($resB['data']->data, function ($value, $key) use ($countArt) {
                        return $value->quantity >= $countArt[$value->sku];
                    });

                    if (count($obj)) {
                        return true;
                    }
                }
            }
        }

        return false;
    }


    public static function baseResponse($status, $message, $data, $code = 200)
    {
        $response = [
            "status" => $status == true ? "success" : "failure",
            //"success" => $status,
            "message" => $message,
            "data" => $data
        ];

        return response()->json($response, $code);
    }

    public static function normaliza($cadena = '', $isANS = true)
    {
        $originales = 'ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝÞßàáâãäåæçèéêëìíîïðñòóôõöøùúûýýþÿŔŕ';
        $modificadas = 'aaaaaaaceeeeiiiidnoooooouuuuybsaaaaaaaceeeeiiiidnoooooouuuyybyRr';
        $cadena = utf8_decode($cadena);
        $cadena = strtr($cadena, utf8_decode($originales), $modificadas);
        $cadena = strtolower($cadena);
        $cadena = utf8_encode($cadena);
        if ($isANS) {
            $cadena = str_replace(',', '', $cadena);
        }

        return $cadena;
    }

    /**
     * [getOptionColumn description]
     * @param  [type] $table [nombre de la tabla de BD que deseo usar]
     * @param  [type] $field [Nombre de la columna de tipo enum a listar]
     * @return [type]        [description]
     */
    /* public static function getOptionColumn($table, $field)
    {
        
        $test = DB::select(DB::raw("show columns from {$table} where field = '{$field}'"));

        preg_match('/^enum\((.*)\)$/', $test[0]->Type, $matches);
        foreach (explode(',', $matches[1]) as $value) {
            $enum[] = trim($value, "'");
        }
        asort($enum);
        return $enum;
    } */

    public static function getOptionColumn($table, $field)
    {
        // Consulta usando cadenas directamente en lugar de DB::raw
        $test = DB::select("SHOW COLUMNS FROM `{$table}` WHERE Field = '{$field}'");

        if (empty($test)) {
            // No se encontraron columnas con ese nombre
            return [];
        }

        // Usar expresión regular para extraer los valores ENUM
        preg_match('/^enum\((.*)\)$/', $test[0]->Type, $matches);
        $enum = [];

        if (!empty($matches)) {
            foreach (explode(',', $matches[1]) as $value) {
                $enum[] = trim($value, "'");
            }
        }

        asort($enum);
        return $enum;
    }


    public static function decodificarBase64($cadena)
    {
        if (self::isBase64($cadena)) {
            return base64_decode($cadena);
        }
        return $cadena;
    }

    public static function codificarBase64($cadena) {
        if (!self::isBase64($cadena)) {
            return base64_encode($cadena);
        }
        return $cadena;
    }
    

    public static function isBase64($cadena)
    {
        if (base64_decode($cadena, true) !== false && !is_numeric($cadena)) {
            return true;
        }
        return false;
    }

    /**
     * [getTokenConctact retorna una cadena con el formato: ABC123]
     * @param  integer $tam_L  [cantidad de letras]
     * @param  integer $tam_N  [cantidad de numeros]
     * @param  string  $type_L [Tipo de letras]
     * @return [type]          [description]
     */
    public static function getTokenVerify($tam_L = 0, $type_L = 'upper', $tam_N = 4)
    {
        $num = self::getRandDig($tam_N);
        $let = "";
        if ($tam_L > 0) {
            $let = self::getRandText($tam_L, $type_L);
        }
        return $let . $num;
    }


    /**
     *  Optiene mapa de rutas asociadas a las politicas de permisologia
     *
     *  @return Array
     */
    public static function getMapRoute()
    {
        return [
            //Ingreso al seller
            'APV-DSE' => [
                'login',
                'dashboard',
                'dashboard.serviciability',
                'getTotalSalesByDate',
                'installments.checkRequest',
                'installments.acceptRequest',
                'installments.sellerRequests',
                'installments.pendingPaySeller',
                'installments.findClient',
                'installments.finalStep',
                'installments.getPendingPay',
                'installments.doPay',
                'installments.payNotification',
                'seller.comparative',
                'testCoppels',
                'test.viewEmail',
                'test.testEmail',
                'test.mitUpdate',
                'findRelationUsers',
                'dashboard.regconex'
            ],

            //Listar prospectos
            'LCL-DSE' => [
                'client.list',
                'client.listAjax',
                'seller.findClient',
                'seller.showClientN'
            ],

            //Registrar prospecto
            'RCL-DSE' => [
                'client.register',
                'client.registerAjax'
            ],

            //crear nueva cita
            'CDV-DSE' => [
                'date.new',
                'call.newschedule',
                'call.listDate'
            ],

            //Lista de citas
            'LCV-DSE' => [
                'client.scheduleList',
                'client.getSchedule'
            ],

            //Altas
            'ACV-DSE' => [
                'seller.index',
                'seller.showPacks',
                'seller.showPackMov',
                //'seller.find',
                'seller.getArticle',
                'seller.processSale',
                //'seller.showClient',
                'seller.validNumberSale',
                'seller.validQtyDns',
                'inventory.listDNOOR',
                'inventory.searchListDN_OR',
                'inventory.downloadInvNoty',
                'seller.validIdentity',
                'seller.checkValidIdentity',
                'inventory.changeStatus',
                'inventory.verifyDnStatus',
                'inventory.chekingRequestStatus'
            ],

            //Altas en abono, para vender en abono se necesita tambien ACV-DSE
            'DSI-DSE' => [],

            //Desbloqueo de produto
            'ARV-DSE' => [
                'seller.onlyProduct',
                'seller.getPackProduct',
                'seller.confirmSaleProduct',
                'seller.doSaleProduct'
            ],

            //Permiso para mostrar mapa en dashboard
            'MAP-DSE' => [],

            //Permiso para mostrar mapa a un vendedor (venta producto)
            'MAP-SEL' => [],

            //Permiso para descargar csv de inventario en el dashboard
            'DCI-DSE' => [
                'dashboard.downloadInv'
            ],

            //Estatus de la linea
            'SMV-DSE' => [
                'seller.statusNumber'
            ],

            //No se esta usando
            'HSV-DSE' => [
                'seller.history'
            ],

            //recargas
            'RSC-DSE' => [
                'charger.index',
                'charger.find',
                //'charger.process',
            ],

            //Edita prospecto
            'EPD-DSE' => [
                'client.edit'
            ],

            //Edita una cita
            'ECV-DSE' => [
                'client.editschedule',
                'call.listDate'
            ],

            //Listado de clientes
            'LCN-DSE' => [
                'client.listClient',
                'client.listClientAjax'
            ],

            //movimiento de inventario
            'A1V-G1V' => [
                'coordination.stock',
                'coordination.findSeller',
                'coordination.findInveSeller',
                'coordination.addStock',
                'coordination.removeStock',
                'findRelationUsers',
                'inventory.preassignedStatus'
            ],

            //Movimiento de inventarion para jefe de instaladores
            'A2V-G2V' => [
                'inventory.installers.stock',
                'findRelationInstallers',
                'inventory.installers.findInveInstaller',
                'inventory.installers.addStock',
                'inventory.installers.removeStock'
            ],
            //Recepcion de dinero
            'RMV-DSE' => [
                'coordination.reception',
                'coordination.findSeller',
                'coordination.getSalesPayoff',
                'coordination.receptionNoti',
                'coordination.receptionList',
                'coordination.receptionStatus'
            ],

            //Editar un cliente
            'ECD-DSE' => [
                'clientNP.edit'
            ],

            //registrar dn de brightstar
            /*'REG-BRS' => [
      'brightstar.registerDn',
      'brightstar.getOrders',
      'brightstar.processOrders',
      ],*/

            //Notificar entrega de efectivo - vendedor
            'NMD-DSE' => [
                'seller.cashDelivery',
                'seller.cashDeliveryDeny'
            ],

            //Reporte de altas para coordinador
            'ACT-DSE' => [
                'coordination.reportActivations',
                'coordination.getReportActivarions',
                'coordination.setPermits',
                'coordination.getReportUnConcSales',
                'coordination.reportUnConcSales'
            ],

            //Reporte de fibra
            'REP-IPS' => [
                'fiber.getFiberPendingReport'
            ],

            //Reporte de pre-ventas de fibra
            'FIB-PRE' => [
                'fiber.reportPreSales',
                'fiber.getReportPreSales',
                'fiber.viewDetailPreSaleItem'
            ],

            //Nomina
            'NOM-DSE' => [
                'Nomina.index',
                'Nomina.getFile',
                'Nomina.getFileContract'
            ],

            //Gestion de ventas en abono
            'SEL-PSI' => [
                'installments.reportsMI',
                'installments.requests',
                'installments.pendingPay'
            ],

            //Reporte de conciliaciones
            'CRV-DSE' => [
                'coordination.reportConcilations',
                'coordination.reportgetConcilations',
                'coordination.downloadReportConc'
            ],

            //Venta movilidad
            'SEL-MOV' => [
                'seller.index',
                'seller.validImei',
                'seller.validQtyDns',
                'payjoy.savePayjoy',
                'payjoy.verifyPayjoy',
                'payjoy.associatePayjoy',
                'inventory.listDNOOR',
                'inventory.searchListDN_OR',
                'inventory.downloadInvNoty',
                'seller.validIdentity',
                'seller.checkValidIdentity',
                'paguitos.associatePaguitos',
                'paguitos.verifyPaguitos',
                'paguitos.savePaguitos',
                'client.getByDn'
            ],

            //Venta de mifi
            'SEL-MIF' => [
                'seller.index',
                'inventory.listDNOOR',
                'inventory.searchListDN_OR',
                'inventory.downloadInvNoty',
                'seller.validIdentity',
                'seller.checkValidIdentity'
            ],

            //Migraciones
            'MIG-DSE' => [
                'seller.migrations',
                'seller.findClientMigration',
                'seller.updateClientM',
                'seller.doMigration'
            ],

            //Venta de fibra
            'SEL-FIB' => [
                'sellerFiber.index',
                'seller.findClient',
                'client.registerAjax',
                'sellerFiber.showClient',
                'sellerFiber.getMapCoverage',
                'sellerFiber.getPlanes',
                'sellerFiber.getPlan',
                'seller.findInstaller',
                'seller.updateClientM',
                'sellerFiber.regInstall',
                'sellerFiber.detailPendingPaidInsModal',
                'sellerFiber.markAsPaidInstall',
                'sellerFiber.getCompAddress',
                'inventory.listDNOOR',
                'inventory.searchListDN_OR',
                'inventory.downloadInvNoty',
                'seller.validIdentity',
                'seller.checkValidIdentity',
                'sellerFiber.payPending',
                'sellerFiber.payPendingAjax',
                'sellerFiber.getCitys',
                'sellerFiber.getOlts',
                'sellerFiber.getNodesRed',
                'sellerFiber.chekingCoverageFiber',
                'sellerFiber.getCoordFromAddress',
                'sellerFiber.getCalendar',
                'sellerFiber.getClock',
                'sellerFiber.getQrForce',
                'sellerFiber.sendMailQr',
                'sellerFiber.verifyQr',
                'seller.validImei',
                'sellerFiber.cantToken',
                'sellerFiber.newToken',
                'sellerFiber.verifyPhone',
                'sellerFiber.requestAutorized',
                'sellerFiber.checkingAutorized',
                'sellerFiber.reSendForceURL',
                'sellerFiber.sendCircleForm',
                'sellerFiber.getCircleForm',
                // 'sellerFiber.apreciacionCircle',
                'sellerFiber.upPhotoEvidency',
                'sellerFiber.getQuestionCircle',
                'sellerFiber.registerNewCheking',
                'sellerFiber.checkingCircleForm'
            ],

            //Instalador de fibra
            'SEL-INF' => [
                'seller.findInstaller',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal',
                'sellerFiber.deleteInstall',
                'sellerFiber.loadMoredetailInsModal',
                'sellerFiber.doInstall',
                'sellerFiber.getMSISDNSFiber',
                'sellerFiber.doRegister',
                'sellerFiber.getMSISDNGenerate',
                'sellerFiber.chekingMac',
                'sellerFiber.installerSurvey',
                'sellerFiber.doSurvey',
                'sellerFiber.upPhotoEvidency',
                'sellerFiber.sendMailQr',
                'sellerFiber.verifyQr',
                'sellerFiber.setQrForce',
                'sellerFiber.getPlan',
                'sellerFiber.getPaymentSubscrip',
                'sellerFiber.changer_incash',
                'sellerFiber.cancelQrPayment',
                'sellerFiber.reloadQrPayment',
                'sellerFiber.getMailPayment',
                'sellerFiber.setMailPayment',
                'sellerFiber.setChangerPack',
                'sellerFiber.sendMailQrPayment',
                'sellerFiber.verifyPayment',
                'sellerFiber.getInstallerCharges',
                'sellerFiber.verifyInfoPort',
                'sellerFiber.findInventoryAsigned',
                'sellerFiber.viewProcessFail',
                'sellerFiber.processFail',
                'sellerFiber.refresFail',
                'sellerFiber.refresComponent',
                'sellerFiber.changeMac',
                'sellerFiber.initProvision',
                'sellerFiber.initReProvision',
                'sellerFiber.checkingActiveFiber',
                'sellerFiber.getListSupplies',
                'sellerFiber.validateEndProvision',
                'sellerFiber.viewCardDetail'
            ],

            //Asignar cita a instaladores
            'FIB-AIC' => [
                'sellerFiber.getListInstaller'
            ],

            //cancelar cita de instalacion
            'FIB-SMC' => [
                'sellerFiber.getTypification',
                'sellerFiber.cancelInstalation'
            ],

            //Listado de Guias pendientes
            'LST-GIP' => [
                'inventory.pendingFolios',
                'inventory.boxDetail',
                'inventory.acceptBoxDetail'
            ],

            //Realiza Soporte de fibra
            'FIB-PSP' => [
                'sellerFiber.viewCardDetail',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal',
                'sellerFiber.upPhotoEvidency'
            ],

            //Crear Soporte de fibra
            'FIB-CSF' => [
                'client.viewSupportClient',
                'client.createSupport',
                'client.deleteSupport'
            ],

            //Crear atenciones de fibra
            'FIB-ATC' => [
                'client.viewSupportClient',
                'client.createFiberAttention'
            ],

            //citas de instalaciones por asignar
            'FIB-VAC' => [
                'sellerFiber.viewCardDetail',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal'
            ],

            //citas de instalaciones asignadas a instaladores
            'FIB-VLC' => [
                'sellerFiber.viewCardDetail',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal'
            ],

            //citas de instalaciones confirmadas para la ciudad y que aun no tiene responsable
            'FIB-ASS' => [
                'sellerFiber.viewCardDetail',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal'
            ],

            //citas de soporte por asignar
            'SUP-VIE' => [
                'sellerFiber.viewCardDetail',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal'
            ],

            //citas de soporte asignados a los instaladores
            'SUP-ASI' => [
                'sellerFiber.viewCardDetail',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal'
            ],

            //citas de soporte asignados a los instaladores
            'FIB-VSC' => [
                'sellerFiber.viewCardDetail',
                'sellerFiber.detailInsModal',
                'sellerFiber.saveDetailInsModal'
            ],

            //Aceptar o rechazar inventario
            'SEL-ARI' => [
                'inventory.preassigned',
                'inventory.rejectPreassignedInv',
                'inventory.acceptPreassignedInv'
            ],

            //Bajas de vendedores
            'SEL-LOW' => [
                'low.new-request',
                'coordination.findInveSeller',
                'low.getSalesUser',
                'low.getDeudaUser',
                'low.regLowUser',
                'low.viewRequestsList',
                'low.getRequestsList',
                'low.low-install',
                'low.view-install'
            ],

            //Permiso Ver estados de Deudas
            'EDC-DSE' => [
                'coordination.reportDebtStatus',
                'coordination.reportgetDebtStatus',
                'coordination.reportgetDebtStatusUps',
                'coordination.reportgetDebtStatusCha',
                'coordination.reportgetDebtStatusRec',
                'coordination.reportgetDebtStatusDel',
                'coordination.reportgetDebtStatusDep'
            ],

            //Venta de telefonia por telmovPay
            'SEL-TLP' => [
                'seller.chekingIdentiTelmov',
                'seller.listModelSmartPhone',
                //'telmovpay.asociateFinanceTelmov',
                'telmovpay.initTelmov',
                // 'telmovpay.verifyInitTelmov',
                'telmovpay.updateConctactClient',
                'telmovpay.step1InitFinace',
                'telmovpay.chekingMail',
                'telmovpay.cancelTelmov',
                'telmovpay.requestQr',
                'telmovpay.requestQrVerifyLast',
                //'telmovpay.associateCashTelmov',
                'telmovpay.buildPlan',
                'telmovpay.getModels',
                'telmovpay.initContract',
                'telmovpay.endContract',
                'telmovpay.endEnrole',
                'telmovpay.sincronizeApp'
            ],

            //Permiso Realizar ventas en sitio
            'SEL-PSE' => [
                'PointSellerIndex',
                'PointSellerFind',
                'PointSellerServices',
                'PointSellerRecharges'
            ],

            //Permiso Ver estados de Deudas
            'SEL-PSA' => [
                'PointSellerAudit.index'
            ],

            //Permiso Vender dispositivos
            'SEL-DIS' => [
                'seller.listDispositiveSales',
                'seller.listPaymentDisp',
                'seller.findInvDispSale',
                'seller.viewInvDetailSale',
                'seller.registerSaleDisp',
                'seller.viewUniqueAsigne'
            ],

            //Permiso para editar datos de contacto que han sido verificados
            'CLI-CNT' => []
        ];
    }


    public static  function sendEventFiberToWebhookSeller($data, $email){

		$webhook = DB::table('islim_users')
					->select('webhook_fiber')
					->where([
						['email', $email]
					])->first();
				
		$webhook = $webhook->webhook_fiber ?? null;

		if($webhook == null) return false;

		$curl = curl_init();

		curl_setopt_array($curl, array(
			CURLOPT_URL => $webhook,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => "",
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 60,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => "POST",
			CURLOPT_POSTFIELDS => json_encode($data),
			CURLOPT_HTTPHEADER => array(
				"accept: */*",
				"Content-Type: application/json",
				"cache-control: no-cache",
				"accept-language: en-US,en;q=0.8"
			),
		));

		$response = curl_exec($curl);
		$httpcode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
		$err = curl_error($curl);

		curl_close($curl);

		return $response;
	}
    
}
