<?php

namespace App\Utilities;


use App\Models\LogApiV2;

use App\Utilities\Common;
use App\Utilities\CustomLogs;

/*Clase que contiene metodos para consultas con api de google*/

class Google
{
	/*
		Consulta informacion de dada una direccion

		@param String $address
		@return Object
	*/
	public static function getAddressInfo($address = false, $request = false, LogApiV2 $log = null)
	{
		if ($address) {
			$address = urlencode($address);

			$url = "https://maps.googleapis.com/maps/api/place/textsearch/json?query=" . $address . "&key=" . env('GOOGLE_MAP_KEY');

			$data = Common::executeCurl($url, 'GET');

			if ($data['success'] && $data['data']->status == 'OK' && !empty($data['data']->results)) {
				return ['success' => true, 'data' => $data['data']->results];
			}

			if ($request) {
				CustomLogs::registerLog(
					'notice',
					'Error al obtener información de la dirección desde google (getAddressInfo)',
					'F',
					$request,
					$data
				);
			}
		}

		if (!empty($log)) {
			CustomLogs::addMessage(
				'Error al obtener información de la dirección desde google (getAddressInfo)',
				$log
			);
		}

		return ['success' => false, 'data' => !empty($data) ? $data : false];
	}

	public static function getAddreddFromLatLng($lat = false, $lng = false, $request = false, LogApiV2 $log = null)
	{
		if ($lat && $lng) {
			$url = "https://maps.googleapis.com/maps/api/geocode/json?latlng=" . $lat . "," . $lng . "&key=" . env('GOOGLE_MAP_KEY');

			$data = Common::executeCurl($url, 'GET');

			if ($data['success'] && $data['data']->status == 'OK' && !empty($data['data']->results)) {
				return ['success' => true, 'data' => $data['data']->results[0]->formatted_address];
			}

			if ($request) {
				CustomLogs::registerLog(
					'notice',
					'Error al obtener lat y lng desde la dirección (getAddreddFromLatLng)',
					'F',
					$request,
					$data
				);
			}
		}

		if (!empty($log)) {
			CustomLogs::addMessage(
				'Error al obtener lat y lng desde la dirección (getAddreddFromLatLng)',
				$log
			);
		}

		return ['success' => false, 'data' => !empty($data) ? $data : false];
	}

	public static function getAddressDetail($palceId = false, $request = false, LogApiV2 $log = null)
	{
		if ($palceId) {
			$url = "https://maps.googleapis.com/maps/api/place/details/json?placeid=" . $palceId . "&key=" . env('GOOGLE_MAP_KEY');

			$data = Common::executeCurl($url, 'GET');

			if ($data['success'] && $data['data']->status == 'OK' && !empty($data['data']->result)) {
				return ['success' => true, 'data' => $data['data']->result];
			}

			if ($request) {
				CustomLogs::registerLog(
					'notice',
					'Error al obtener detalle de la dirección (getAddressDetail)',
					'F',
					$request,
					$data
				);
			}
		}

		if (!empty($log)) {
			CustomLogs::addMessage(
				'Error al obtener detalle de la dirección (getAddressDetail)',
				$log
			);
		}

		return ['success' => false, !empty($data) ? $data : false];
	}
}
