<?php

namespace App\Utilities;

use App\Utilities\Common;

use Illuminate\Support\Arr;

//Modelos
use App\Models\LogApiV2;

class prova
{
	public static function getPrice($postal_code = false, $skus = [])
	{
		if ($postal_code && count($skus)) {
			$res = Common::executeCurl(
				env('URL_PROVA') . 'price',
				'POST',
				[
					"Content-Type: application/json",
					"Authorization: Bearer " . env('TOKEN_PROVA'),
					"Content-Type: application/json"
				],
				[
					'postal_code' => $postal_code,
					'skus' => $skus
				]
			);

			if ($res['success'] && !empty($res['data']) && $res['data']->success) {
				return ['success' => true, 'data' => $res['data']->data];
			}

			return [
				'success' => false,
				'data' => 'Error consultando precio.',
				'original' => $res
			];
		}

		return ['success' => false, 'data' => 'Error consultando precio, faltan parametros.'];
	}

	public static function getInventary($wh = false, $skus = [])
	{
		if ($wh && count($skus)) {
			$res = Common::executeCurl(
				env('URL_PROVA') . 'inventory',
				'POST',
				[
					"Content-Type: application/json",
					"Authorization: Bearer " . env('TOKEN_PROVA'),
					"Content-Type: application/json"
				],
				[
					'warehouse' => $wh,
					'skus' => $skus
				]
			);

			if ($res['success'] && !empty($res['data']) && $res['data']->success) {
				return ['success' => true, 'data' => $res['data']->data[0]];
			}

			return [
				'success' => false,
				'data' => 'Error consultando inventario.',
				'original' => $res
			];
		}

		return ['success' => false, 'data' => 'Error consultando inventario, faltan parametros.'];
	}

	public static function makeDelivery($car_id = false, $transaction = false)
	{
		if ($car_id && $transaction) {
			$res = Common::executeCurl(
				env('URL_PROVA') . 'make-delivery',
				'POST',
				[
					"Content-Type: application/json",
					"Authorization: Bearer " . env('TOKEN_PROVA'),
					"Content-Type: application/json"
				],
				[
					'car_id' => $car_id,
					'transaction' => $transaction,
					'origin' => 'API-SELLER'
				]
			);

			if ($res['success'] && !empty($res['data']) && $res['data']->success) {
				return ['success' => true, 'data' => $res['data']->data];
			}

			return ['success' => false, 'data' => 'No se pudo crear el delivery', 'original' => $res];
		}

		return ['success' => false, 'data' => 'No se pudo crear el delivery faltan parametros.'];
	}

	public static function validateInventory($deposit, $skus = [], LogApiV2 $log = null)
	{
		$invProv = self::getInventary($deposit, $skus);

		if ($invProv['success']) {
			$obj = Arr::where(
				$invProv['data']->inventary,
				function ($value, $key) use ($skus) {
					$qtySKU = array_count_values($skus);

					return in_array($value->sku, $skus) && $value->qty_available >= $qtySKU[$value->sku];
				}
			);

			if (count($obj) == count($skus)) {
				return true;
			}
		}

		if (!empty($log)) {
			CustomLogs::addMessage(
				'respuesta de inventario: ' . json_encode($invProv),
				$log
			);
		}

		return false;
	}

	public static function getShippingArray($postal_code = false, $skus = [], $provaMth = false, $request = false, LogApiV2 $log = null)
	{
		$msgError = 'Error en metodo (prova::getShippingArray)';

		if ($postal_code && count($skus) && $provaMth) {
			//Consultando precio prova
			$prova = self::getPrice($postal_code, $skus);

			if ($prova['success'] && !empty($prova['data']->prices)) {
				//validando inventario y disponibilidad de prova
				$hasInv = self::validateInventory($prova['data']->warehouse, $skus, $log);

				if ($hasInv) {
					return [
						'id' => $provaMth->code_name,
						'currier' => $prova['data']->currier,
						'name' => $provaMth->Name,
						'price' => $prova['data']->prices[0]->price,
						'sub_request' => false,
						'aprox_time_hrs' => env('TIME_PROV'),
						'sending_data' => [
							'route' => '',
							'street_number' => '',
							'neighborhood' => '',
							'sub_locality' => '',
							'locality' => '',
							'state' => '',
							'notes' => '',
							'postal_code' => $postal_code
						]
					];
				} else {
					$msgError = 'artículo(s) sin inventario en prova (prova::getShippingArray) ' . json_encode($skus);
				}
			} else {
				$msgError = 'Error consultando precio (prova::getShippingArray)';

				if ($request) {
					CustomLogs::registerLog(
						'error',
						$msgError,
						'F',
						$request,
						$prova
					);
				}

				//$msgError = $msgError.' '.json_encode($prova);
			}
		}

		if (!empty($log)) {
			CustomLogs::addMessage(
				$msgError,
				$log
			);
		}

		return [];
	}
}
